@@ -32,7 +32,7 @@ public:
 
     QMap<QString, QString> documentProperties; //core, app and custom properties
     QSharedPointer<Workbook> workbook;
-    QSharedPointer<ContentTypes> contentTypes;
+    std::shared_ptr<ContentTypes> contentTypes;
 	bool isLoad; 
 };
 
