@@ -571,7 +571,7 @@ bool Workbook::loadFromXmlFile(QIODevice *device)
 
                  const auto& name = attributes.value(QLatin1String("name")).toString();
 
-                 int sheetId = attributes.value(QLatin1String("sheetId")).toString().toInt();
+                 int sheetId = attributes.value(QLatin1String("sheetId")).toInt();
 
                  const auto& rId = attributes.value(QLatin1String("r:id")).toString();
 
@@ -612,10 +612,8 @@ bool Workbook::loadFromXmlFile(QIODevice *device)
                  QString strFilePath = filePath();
 
                  // const QString fullPath = QDir::cleanPath(splitPath(strFilePath).constFirst() + QLatin1String("/") + relationship.target);
-                 QString str = *( splitPath(strFilePath).begin() );
-                 str = str + QLatin1String("/");
-                 str = str + relationship.target;
-                 const QString fullPath = QDir::cleanPath( str );
+                 const auto parts = splitPath(strFilePath);
+                 QString fullPath = QDir::cleanPath(parts.first() + QLatin1String("/") + relationship.target);
 
                  sheet->setFilePath(fullPath);
              }
@@ -637,17 +635,17 @@ bool Workbook::loadFromXmlFile(QIODevice *device)
                         {
                             QXmlStreamAttributes attrs = reader.attributes();
                             if (attrs.hasAttribute(QLatin1String("xWindow")))
-                                d->x_window = attrs.value(QLatin1String("xWindow")).toString().toInt();
+                                d->x_window = attrs.value(QLatin1String("xWindow")).toInt();
                             if (attrs.hasAttribute(QLatin1String("yWindow")))
-                                d->y_window = attrs.value(QLatin1String("yWindow")).toString().toInt();
+                                d->y_window = attrs.value(QLatin1String("yWindow")).toInt();
                             if (attrs.hasAttribute(QLatin1String("windowWidth")))
-                                d->window_width = attrs.value(QLatin1String("windowWidth")).toString().toInt();
+                                d->window_width = attrs.value(QLatin1String("windowWidth")).toInt();
                             if (attrs.hasAttribute(QLatin1String("windowHeight")))
-                                d->window_height = attrs.value(QLatin1String("windowHeight")).toString().toInt();
+                                d->window_height = attrs.value(QLatin1String("windowHeight")).toInt();
                             if (attrs.hasAttribute(QLatin1String("firstSheet")))
-                                d->firstsheet = attrs.value(QLatin1String("firstSheet")).toString().toInt();
+                                d->firstsheet = attrs.value(QLatin1String("firstSheet")).toInt();
                             if (attrs.hasAttribute(QLatin1String("activeTab")))
-                                d->activesheetIndex = attrs.value(QLatin1String("activeTab")).toString().toInt();
+                                d->activesheetIndex = attrs.value(QLatin1String("activeTab")).toInt();
                         }
                     }
                 }
@@ -660,10 +658,8 @@ bool Workbook::loadFromXmlFile(QIODevice *device)
 
                  QSharedPointer<SimpleOOXmlFile> link(new SimpleOOXmlFile(F_LoadFromExists));
 
-                 QString str = *( splitPath(filePath()).begin() );
-                 str = str + QLatin1String("/");
-                 str = str + relationship.target;
-                 const QString fullPath = QDir::cleanPath( str );
+                 const auto parts = splitPath(filePath());
+                 QString fullPath = QDir::cleanPath(parts.first() + QLatin1String("/") + relationship.target);
 
                  link->setFilePath(fullPath);
                  d->externalLinks.append(link);
@@ -675,7 +671,7 @@ bool Workbook::loadFromXmlFile(QIODevice *device)
                  if (attrs.hasAttribute(QLatin1String("comment")))
                      data.comment = attrs.value(QLatin1String("comment")).toString();
                  if (attrs.hasAttribute(QLatin1String("localSheetId"))) {
-                     int localId = attrs.value(QLatin1String("localSheetId")).toString().toInt();
+                     int localId = attrs.value(QLatin1String("localSheetId")).toInt();
                      int sheetId = d->sheets.at(localId)->sheetId();
                      data.sheetId = sheetId;
                  }
@@ -690,7 +686,7 @@ bool Workbook::loadFromXmlFile(QIODevice *device)
 /*!
  * \internal
  */
-QList<QSharedPointer<MediaFile> > Workbook::mediaFiles() const
+QList<std::shared_ptr<MediaFile> > Workbook::mediaFiles() const
 {
     Q_D(const Workbook);
 
@@ -700,7 +696,7 @@ QList<QSharedPointer<MediaFile> > Workbook::mediaFiles() const
 /*!
  * \internal
  */
-void Workbook::addMediaFile(QSharedPointer<MediaFile> media, bool force)
+void Workbook::addMediaFile(std::shared_ptr<MediaFile> media, bool force)
 {
     Q_D(Workbook);
 
