@@ -300,7 +300,7 @@ public:
 	void setParentAspect(AbstractAspect*);
 	Folder* folder();
 	bool isDescendantOf(AbstractAspect* other);
-	void addChild(AbstractAspect*);
+	virtual bool addChild(AbstractAspect*);
 	void addChildFast(AbstractAspect*);
 	virtual void finalizeAdd(){};
 	QVector<AbstractAspect*> children(AspectType, ChildIndexFlags = {}) const;
@@ -398,7 +398,8 @@ public:
 	}
 
 	// undo/redo related functions
-	void setUndoAware(bool);
+	void setUndoAware(bool value);
+	bool isUndoAware() const;
 	virtual QUndoStack* undoStack() const;
 	void exec(QUndoCommand*);
 	void exec(QUndoCommand* command,
