@@ -24,9 +24,12 @@
 #include "backend/worksheet/plots/cartesian/Histogram.h"
 #include "backend/worksheet/plots/cartesian/KDEPlot.h"
 #include "backend/worksheet/plots/cartesian/LollipopPlot.h"
+#include "backend/worksheet/plots/cartesian/ProcessBehaviorChart.h"
 #include "backend/worksheet/plots/cartesian/QQPlot.h"
+#include "backend/worksheet/plots/cartesian/RunChart.h"
 #include "backend/worksheet/plots/cartesian/Value.h"
 #include "backend/worksheet/plots/cartesian/XYFitCurve.h"
+#include "backend/worksheet/plots/cartesian/XYFunctionCurve.h"
 #ifdef HAVE_LIBORIGIN
 #include "backend/datasources/projects/OriginProjectParser.h"
 #endif
@@ -57,13 +60,12 @@
 
 // required to parse Cantor and Jupyter files
 #ifdef HAVE_CANTOR_LIBS
-#include "backend/cantorWorksheet/CantorWorksheet.h"
+#include "backend/notebook/Notebook.h"
 #include <KZip>
 #include <QDomDocument>
 #include <QJsonDocument>
 #include <QJsonObject>
 #include <QJsonParseError>
-#include <cantor/backend.h>
 #endif
 
 namespace {
@@ -71,7 +73,7 @@ namespace {
 // the project version will be compared with this.
 // if you make any imcompatible changes to the xmlfile
 // or the function in labplot, increase this number.
-int buildXmlVersion = 12;
+int buildXmlVersion = 16;
 }
 
 /**
@@ -255,15 +257,8 @@ QUndoStack* Project::undoStack() const {
 }
 
 QMenu* Project::createContextMenu() {
-	QMenu* menu = AbstractAspect::createContextMenu();
-
-	// add close action
-	menu->addSeparator();
-	menu->addAction(QIcon::fromTheme(QLatin1String("document-close")), i18n("Close"), this, SIGNAL(closeRequested()));
-
-	// add the actions from MainWin
-	Q_EMIT requestProjectContextMenu(menu);
-
+	QMenu* menu = AbstractAspect::createContextMenu(); // add default actions from Aspect
+	Q_EMIT requestProjectContextMenu(menu); // add the actions from MainWin
 	return menu;
 }
 
@@ -488,6 +483,7 @@ void Project::save(const QPixmap& thumbnail, QXmlStreamWriter* writer) {
 	writer->writeAttribute(QStringLiteral("xmlVersion"), QString::number(buildXmlVersion));
 	writer->writeAttribute(QStringLiteral("modificationTime"), modificationTime().toString(QStringLiteral("yyyy-dd-MM hh:mm:ss:zzz")));
 	writer->writeAttribute(QStringLiteral("author"), author());
+	writer->writeAttribute(QStringLiteral("saveCalculations"), QString::number(d->saveCalculations));
 
 	// save the state of the content dock widgets
 	writer->writeAttribute(QStringLiteral("dockWidgetState"), d->dockWidgetState);
@@ -497,9 +493,6 @@ void Project::save(const QPixmap& thumbnail, QXmlStreamWriter* writer) {
 	if (d->saveDefaultDockWidgetState)
 		writer->writeAttribute(QStringLiteral("defaultDockWidgetState"), d->defaultDockWidgetState);
 
-	if (d->saveCalculations)
-		writer->writeAttribute(QStringLiteral("saveCalculations"), QString::number(d->saveCalculations));
-
 	QString image;
 	if (!thumbnail.isNull()) {
 		QByteArray bArray;
@@ -561,11 +554,7 @@ bool Project::load(const QString& filename, bool preview) {
 			KMessageBox::error(nullptr, i18n("The project file is empty."), i18n("Error opening project"));
 			return false;
 		}
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
 		QDEBUG(Q_FUNC_INFO << ", got magic: " << magic << Qt::hex << "0x" << magic)
-#else
-		QDEBUG(Q_FUNC_INFO << ", got magic: " << magic << hex << "0x" << magic)
-#endif
 
 		if (magic == 0xfd37) // XZ compressed data
 			file = new KCompressionDevice(filename, KCompressionDevice::Xz);
@@ -634,13 +623,8 @@ bool Project::load(const QString& filename, bool preview) {
 			"If you modify and save the project, the CAS content will be lost.\n\n"
 			"Do you want to continue?",
 			reader.missingCASWarning());
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
 		auto status = KMessageBox::warningTwoActions(nullptr, msg, i18n("Missing Support for CAS"), KStandardGuiItem::cont(), KStandardGuiItem::cancel());
 		if (status == KMessageBox::SecondaryAction) {
-#else
-		auto status = KMessageBox::warningYesNo(nullptr, msg, i18n("Missing Support for CAS"));
-		if (status == KMessageBox::No) {
-#endif
 			file->close();
 			delete file;
 			return false;
@@ -735,6 +719,7 @@ bool Project::load(XmlStreamReader* reader, bool preview) {
 	return !reader->hasError();
 }
 
+#ifndef SDK
 bool Project::loadNotebook(const QString& filename) {
 	bool rc = false;
 #ifdef HAVE_CANTOR_LIBS
@@ -756,19 +741,19 @@ bool Project::loadNotebook(const QString& filename) {
 				QString backendName = doc.documentElement().attribute(QLatin1String("backend"));
 
 				if (!backendName.isEmpty()) {
-					// create new Cantor worksheet and load the data
-					auto* worksheet = new CantorWorksheet(backendName);
-					worksheet->setName(QFileInfo(filename).fileName());
-					worksheet->setComment(filename);
+					// create new notebook and load the data
+					auto* notebook = new Notebook(backendName);
+					notebook->setName(QFileInfo(filename).fileName());
+					notebook->setComment(filename);
 
 					rc = file.open(QIODevice::ReadOnly);
 					if (rc) {
 						QByteArray content = file.readAll();
-						rc = worksheet->init(&content);
+						rc = notebook->init(&content);
 						if (rc)
-							addChild(worksheet);
+							addChild(notebook);
 						else
-							delete worksheet;
+							delete notebook;
 					} else
 						errorMessage = i18n("Failed to open the file '%1'.", filename);
 				} else
@@ -811,15 +796,15 @@ bool Project::loadNotebook(const QString& filename) {
 						backendName = doc[QLatin1String("metadata")].toObject()[QLatin1String("kernelspec")].toObject()[QLatin1String("language")].toString();
 
 					if (!backendName.isEmpty()) {
-						// create new Cantor worksheet and load the data
-						auto* worksheet = new CantorWorksheet(backendName);
-						worksheet->setName(QFileInfo(filename).fileName());
-						worksheet->setComment(filename);
-						rc = worksheet->init(&content);
+						// create new notebook and load the data
+						auto* notebook = new Notebook(backendName);
+						notebook->setName(QFileInfo(filename).fileName());
+						notebook->setComment(filename);
+						rc = notebook->init(&content);
 						if (rc)
-							addChild(worksheet);
+							addChild(notebook);
 						else
-							delete worksheet;
+							delete notebook;
 					} else
 						rc = false;
 				} else
@@ -844,6 +829,7 @@ bool Project::loadNotebook(const QString& filename) {
 
 	return rc;
 }
+#endif
 
 void Project::retransformElements(AbstractAspect* aspect) {
 	bool hasChildren = aspect->childCount<AbstractAspect>();
@@ -941,9 +927,11 @@ void Project::restorePointers(AbstractAspect* aspect) {
 	// wait until all columns are decoded from base64-encoded data
 	QThreadPool::globalInstance()->waitForDone();
 
-	bool hasChildren = aspect->childCount<AbstractAspect>();
-	const auto& columns = aspect->project()->children<Column>(ChildIndexFlag::Recursive);
-	const auto& histograms = aspect->project()->children<Histogram>(ChildIndexFlag::Recursive); // needed for fit curves only. why a better implementation?
+	// when restoring pointers for an aspect having children, for example a Folder, we need to recursively traverse
+	// all its children and restore the pointers for all of them. Analysis curves, for example XYFitCurve, can also
+	// children (residuals column, note) but there is no need to check the children, the pointers need to be restored
+	// for the analysis curve itself.
+	bool hasChildren = (aspect->childCount<AbstractAspect>() > 0 && !aspect->inherits(AspectType::XYAnalysisCurve));
 
 #ifndef SDK
 	// LiveDataSource:
@@ -956,6 +944,12 @@ void Project::restorePointers(AbstractAspect* aspect) {
 	}
 #endif
 
+	// aspects in the project that can be used as sources/references:
+	auto* project = aspect->project();
+	const auto& columns = project->children<Column>(ChildIndexFlag::Recursive);
+	const auto& histogramsAll = project->children<Histogram>(ChildIndexFlag::Recursive); // needed for fit curves only.
+	const auto& curvesAll = project->children<XYCurve>(ChildIndexFlag::Recursive);
+
 	// xy-curves
 	//  cannot be removed by the column observer, because it does not react
 	//  on curve changes
@@ -968,7 +962,7 @@ void Project::restorePointers(AbstractAspect* aspect) {
 		// list of curves to be retransformed
 		curves << static_cast<XYCurve*>(aspect);
 
-	for (auto* curve : qAsConst(curves)) {
+	for (auto* curve : std::as_const(curves)) {
 		if (!curve)
 			continue;
 		curve->setSuppressRetransform(true);
@@ -982,7 +976,7 @@ void Project::restorePointers(AbstractAspect* aspect) {
 			if (fitCurve) {
 				RESTORE_COLUMN_POINTER(fitCurve, xErrorColumn, XErrorColumn);
 				RESTORE_COLUMN_POINTER(fitCurve, yErrorColumn, YErrorColumn);
-				RESTORE_POINTER(fitCurve, dataSourceHistogram, DataSourceHistogram, Histogram, histograms);
+				RESTORE_POINTER(fitCurve, dataSourceHistogram, DataSourceHistogram, Histogram, histogramsAll);
 			}
 		} else {
 			RESTORE_COLUMN_POINTER(curve, xColumn, XColumn);
@@ -995,7 +989,7 @@ void Project::restorePointers(AbstractAspect* aspect) {
 		}
 
 		if (analysisCurve)
-			RESTORE_POINTER(analysisCurve, dataSourceCurve, DataSourceCurve, XYCurve, curves);
+			RESTORE_POINTER(analysisCurve, dataSourceCurve, DataSourceCurve, XYCurve, curvesAll);
 
 		curve->setSuppressRetransform(false);
 	}
@@ -1010,6 +1004,17 @@ void Project::restorePointers(AbstractAspect* aspect) {
 	for (auto* element : elements)
 		element->assignCurve(curves);
 
+	QVector<XYFunctionCurve*> functionCurves;
+	if (aspect->type() == AspectType::XYFunctionCurve) // check for the type first. InfoElement has children, but they are not relevant here
+		functionCurves << static_cast<XYFunctionCurve*>(aspect);
+	else if (hasChildren)
+		functionCurves = aspect->children<XYFunctionCurve>(ChildIndexFlag::Recursive);
+
+	for (auto* functionCurve : functionCurves) {
+		for (const auto* curve : std::as_const(curves))
+			functionCurve->setFunctionVariableCurve(curve);
+	}
+
 	// axes
 	QVector<Axis*> axes;
 	if (hasChildren)
@@ -1080,15 +1085,16 @@ void Project::restorePointers(AbstractAspect* aspect) {
 			continue;
 
 		// initialize the array for the column pointers
-		int count = boxPlot->dataColumnPaths().count();
+		const auto& paths = boxPlot->dataColumnPaths();
+		int count = paths.count();
 		QVector<const AbstractColumn*> dataColumns;
 		dataColumns.resize(count);
 
 		// restore the pointers
 		for (int i = 0; i < count; ++i) {
 			dataColumns[i] = nullptr;
-			const auto& path = boxPlot->dataColumnPaths().at(i);
-			for (Column* column : columns) {
+			const auto& path = paths.at(i);
+			for (auto* column : columns) {
 				if (!column)
 					continue;
 				if (column->path() == path) {
@@ -1113,7 +1119,8 @@ void Project::restorePointers(AbstractAspect* aspect) {
 			continue;
 
 		// initialize the array for the column pointers
-		int count = barPlot->dataColumnPaths().count();
+		const auto& paths = barPlot->dataColumnPaths();
+		int count = paths.count();
 		QVector<const AbstractColumn*> dataColumns;
 		dataColumns.resize(count);
 
@@ -1121,8 +1128,8 @@ void Project::restorePointers(AbstractAspect* aspect) {
 		for (int i = 0; i < count; ++i) {
 			// data columns
 			dataColumns[i] = nullptr;
-			const auto path = barPlot->dataColumnPaths().at(i);
-			for (Column* column : columns) {
+			const auto& path = paths.at(i);
+			for (auto* column : columns) {
 				if (!column)
 					continue;
 				if (column->path() == path) {
@@ -1157,14 +1164,15 @@ void Project::restorePointers(AbstractAspect* aspect) {
 			continue;
 
 		// initialize the array for the column pointers
-		int count = lollipopPlot->dataColumnPaths().count();
+		const auto& paths = lollipopPlot->dataColumnPaths();
+		int count = paths.count();
 		QVector<const AbstractColumn*> dataColumns;
 		dataColumns.resize(count);
 
 		// restore the pointers
 		for (int i = 0; i < count; ++i) {
 			dataColumns[i] = nullptr;
-			const auto& path = lollipopPlot->dataColumnPaths().at(i);
+			const auto& path = paths.at(i);
 			for (Column* column : columns) {
 				if (!column)
 					continue;
@@ -1180,25 +1188,32 @@ void Project::restorePointers(AbstractAspect* aspect) {
 		RESTORE_COLUMN_POINTER(lollipopPlot, xColumn, XColumn);
 	}
 
-	// data picker curves
-#ifndef SDK
-	QVector<DatapickerCurve*> dataPickerCurves;
+	// process behavior charts/plots
+	QVector<ProcessBehaviorChart*> pbPlots;
 	if (hasChildren)
-		dataPickerCurves = aspect->children<DatapickerCurve>(ChildIndexFlag::Recursive);
-	else if (aspect->type() == AspectType::DatapickerCurve)
-		dataPickerCurves << static_cast<DatapickerCurve*>(aspect);
+		pbPlots = aspect->children<ProcessBehaviorChart>(ChildIndexFlag::Recursive);
+	else if (aspect->type() == AspectType::ProcessBehaviorChart)
+		pbPlots << static_cast<ProcessBehaviorChart*>(aspect);
 
-	for (auto* dataPickerCurve : dataPickerCurves) {
-		if (!dataPickerCurve)
+	for (auto* plot : pbPlots) {
+		if (!plot)
 			continue;
-		RESTORE_COLUMN_POINTER(dataPickerCurve, posXColumn, PosXColumn);
-		RESTORE_COLUMN_POINTER(dataPickerCurve, posYColumn, PosYColumn);
-		RESTORE_COLUMN_POINTER(dataPickerCurve, plusDeltaXColumn, PlusDeltaXColumn);
-		RESTORE_COLUMN_POINTER(dataPickerCurve, minusDeltaXColumn, MinusDeltaXColumn);
-		RESTORE_COLUMN_POINTER(dataPickerCurve, plusDeltaYColumn, PlusDeltaYColumn);
-		RESTORE_COLUMN_POINTER(dataPickerCurve, minusDeltaYColumn, MinusDeltaYColumn);
+		RESTORE_COLUMN_POINTER(plot, dataColumn, DataColumn);
+		RESTORE_COLUMN_POINTER(plot, data2Column, Data2Column);
+	}
+
+	// run charts/plots
+	QVector<RunChart*> runPlots;
+	if (hasChildren)
+		runPlots = aspect->children<RunChart>(ChildIndexFlag::Recursive);
+	else if (aspect->type() == AspectType::RunChart)
+		runPlots << static_cast<RunChart*>(aspect);
+
+	for (auto* plot : runPlots) {
+		if (!plot)
+			continue;
+		RESTORE_COLUMN_POINTER(plot, dataColumn, DataColumn);
 	}
-#endif
 
 	// spreadsheet
 	QVector<Spreadsheet*> spreadsheets;
