@@ -1,12 +1,26 @@
 #ifndef SETTINGS_H
 #define SETTINGS_H
 
-class KConfigGroup;
-
+#include <KConfigGroup>
 #include <KSharedConfig>
 
 namespace Settings {
 
+enum class Type {
+	General,
+	General_Number_Format,
+	General_Units,
+	Worksheet,
+	Spreadsheet,
+#ifdef HAVE_CANTOR_LIBS
+	Notebook,
+#endif
+	Datasets,
+#ifdef HAVE_KUSERFEEDBACK
+	Feedback
+#endif
+};
+
 KConfigGroup group(const QString& name);
 KConfigGroup settingsGeneral();
 bool sync();
@@ -17,6 +31,7 @@ bool sync();
 
 enum class DockPosBehavior { OriginalPos, AboveLastActive };
 SETUP_SETTING2(DockPosBehavior, DockPosBehavior)
+
 }
 
 #endif // SETTINGS_H
