@@ -5,7 +5,7 @@
 	--------------------------------------------------------------------
 	SPDX-FileCopyrightText: 2007-2009 Tilman Benkert <thzs@gmx.net>
 	SPDX-FileCopyrightText: 2010 Knut Franke <knut.franke@gmx.de>
-	SPDX-FileCopyrightText: 2014-2021 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2014-2024 Alexander Semke <alexander.semke@web.de>
 	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -35,9 +35,8 @@
 /**
  * \brief Ctor
  */
-AbstractColumnClearMasksCmd::AbstractColumnClearMasksCmd(AbstractColumnPrivate* col, QUndoCommand* parent)
-	: QUndoCommand(parent)
-	, m_col(col) {
+AbstractColumnClearMasksCmd::AbstractColumnClearMasksCmd(AbstractColumnPrivate* col)
+	: m_col(col) {
 	setText(i18n("%1: clear masks", col->name()));
 	m_copied = false;
 }
@@ -107,9 +106,8 @@ void AbstractColumnClearMasksCmd::finalize() const {
 /**
  * \brief Ctor
  */
-AbstractColumnSetMaskedCmd::AbstractColumnSetMaskedCmd(AbstractColumnPrivate* col, const Interval<int>& interval, bool masked, QUndoCommand* parent)
-	: QUndoCommand(parent)
-	, m_col(col)
+AbstractColumnSetMaskedCmd::AbstractColumnSetMaskedCmd(AbstractColumnPrivate* col, const Interval<int>& interval, bool masked)
+	: m_col(col)
 	, m_interval(interval)
 	, m_masked(masked) {
 	if (masked)
@@ -133,7 +131,7 @@ void AbstractColumnSetMaskedCmd::redo() {
 		m_copied = true;
 	}
 	m_col->m_masking.setValue(m_interval, m_masked);
-	finalize();
+	m_col->owner()->setChanged();
 }
 
 /**
@@ -141,14 +139,7 @@ void AbstractColumnSetMaskedCmd::redo() {
  */
 void AbstractColumnSetMaskedCmd::undo() {
 	m_col->m_masking = m_masking;
-	finalize();
-}
-
-void AbstractColumnSetMaskedCmd::finalize() const {
-	// TODO: implement AbstractColumn::setChanged() instead of these two calls,
-	// move the already available Column::setChanged to the base class.
-	m_col->owner()->invalidateProperties();
-	Q_EMIT m_col->owner()->dataChanged(m_col->owner());
+	m_col->owner()->setChanged();
 }
 
 /** ***************************************************************************
@@ -174,9 +165,8 @@ void AbstractColumnSetMaskedCmd::finalize() const {
 /**
  * \brief Ctor
  */
-AbstractColumnInsertRowsCmd::AbstractColumnInsertRowsCmd(AbstractColumn* col, int before, int count, QUndoCommand* parent)
-	: QUndoCommand(parent)
-	, m_col(col->d)
+AbstractColumnInsertRowsCmd::AbstractColumnInsertRowsCmd(AbstractColumn* col, int before, int count)
+	: m_col(col->d)
 	, m_before(before)
 	, m_count(count) {
 }
@@ -219,9 +209,8 @@ void AbstractColumnInsertRowsCmd::undo() {
 /**
  * \brief Ctor
  */
-AbstractColumnRemoveRowsCmd::AbstractColumnRemoveRowsCmd(AbstractColumn* col, int first, int count, QUndoCommand* parent)
-	: QUndoCommand(parent)
-	, m_col(col->d)
+AbstractColumnRemoveRowsCmd::AbstractColumnRemoveRowsCmd(AbstractColumn* col, int first, int count)
+	: m_col(col->d)
 	, m_first(first)
 	, m_count(count) {
 }
@@ -244,11 +233,8 @@ void AbstractColumnRemoveRowsCmd::undo() {
  * \class AbstractColumnSetHeatmapFormatCmd
  * \brief Set the heatmap format
  ** ***************************************************************************/
-AbstractColumnSetHeatmapFormatCmd::AbstractColumnSetHeatmapFormatCmd(AbstractColumnPrivate* col,
-																	 const AbstractColumn::HeatmapFormat& format,
-																	 QUndoCommand* parent)
-	: QUndoCommand(parent)
-	, m_col(col)
+AbstractColumnSetHeatmapFormatCmd::AbstractColumnSetHeatmapFormatCmd(AbstractColumnPrivate* col, const AbstractColumn::HeatmapFormat& format)
+	: m_col(col)
 	, m_format(format) {
 	setText(i18n("%1: set heatmap format", col->name()));
 }
@@ -274,9 +260,8 @@ void AbstractColumnSetHeatmapFormatCmd::undo() {
  * \class AbstractColumnRemoveHeatmapFormatCmd
  * \brief Set the heatmap format
  ** ***************************************************************************/
-AbstractColumnRemoveHeatmapFormatCmd::AbstractColumnRemoveHeatmapFormatCmd(AbstractColumnPrivate* col, QUndoCommand* parent)
-	: QUndoCommand(parent)
-	, m_col(col) {
+AbstractColumnRemoveHeatmapFormatCmd::AbstractColumnRemoveHeatmapFormatCmd(AbstractColumnPrivate* col)
+	: m_col(col) {
 	setText(i18n("%1: remove heatmap format", col->name()));
 }
 
