@@ -4,7 +4,7 @@
 	Description          : Private data class of Column
 	--------------------------------------------------------------------
 	SPDX-FileCopyrightText: 2007, 2008 Tilman Benkert <thzs@gmx.net>
-	SPDX-FileCopyrightText: 2013-2022 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2013-2024 Alexander Semke <alexander.semke@web.de>
 	SPDX-FileCopyrightText: 2020 Stefan Gerlach <stefan.gerlach@uni.kn>
 	SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -12,7 +12,7 @@
 #ifndef COLUMNPRIVATE_H
 #define COLUMNPRIVATE_H
 
-#include "backend/core/AbstractColumn.h"
+#include "backend/core/AbstractColumnPrivate.h"
 #include "backend/core/column/Column.h"
 #include "backend/lib/IntervalAttribute.h"
 
@@ -21,7 +21,7 @@
 class Column;
 class ColumnSetGlobalFormulaCmd;
 
-class ColumnPrivate : public QObject {
+class ColumnPrivate : public AbstractColumnPrivate {
 	Q_OBJECT
 
 public:
@@ -40,7 +40,11 @@ public:
 	bool copy(const ColumnPrivate*);
 	bool copy(const ColumnPrivate*, int source_start, int dest_start, int num_rows);
 
-	int indexForValue(double x) const;
+	static int calculateMaxSteps(unsigned int value);
+	static int indexForValue(double x, QVector<double>& column, Column::Properties properties, bool smaller);
+	static int indexForValue(const double x, const QVector<QPointF>& column, Column::Properties properties, bool smaller);
+	static int indexForValue(double x, QVector<QLineF>& lines, Column::Properties properties, bool smaller);
+	int indexForValue(double x, bool smaller) const;
 
 	int rowCount() const;
 	int rowCount(double min, double max) const;
@@ -95,6 +99,9 @@ public:
 	void setFormula(int row, const QString& formula);
 	void clearFormulas();
 
+	// settings used to generate random values
+	Column::RandomValuesData randomValuesData;
+
 	QString textAt(int row) const;
 	void setValueAt(int row, QString new_value);
 	void setTextAt(int row, const QString&);
@@ -139,12 +146,7 @@ public:
 
 	struct CachedValuesAvailable {
 		void setUnavailable() {
-			statistics = false;
-			min = false;
-			max = false;
-			hasValues = false;
-			dictionary = false;
-			properties = false;
+			*this = CachedValuesAvailable();
 		}
 		bool statistics{false}; // is 'statistics' already available or needs to be (re-)calculated?
 		// are minMax already calculated or needs to be (re-)calculated?
@@ -201,7 +203,7 @@ public:
 		const QVector<Column::ValueLabel<double>>* valueLabels() const;
 		const QVector<Column::ValueLabel<int>>* intValueLabels() const;
 		const QVector<Column::ValueLabel<qint64>>* bigIntValueLabels() const;
-		int indexForValue(double value) const;
+		int indexForValue(double value, bool smaller) const;
 		double valueAt(int index) const;
 		QDateTime dateTimeAt(int index) const;
 		bool isValid(int index) const;
@@ -237,7 +239,7 @@ public:
 	ValueLabels m_labels;
 	int valueLabelsCount() const;
 	int valueLabelsCount(double min, double max) const;
-	int valueLabelsIndexForValue(double value) const;
+	int valueLabelsIndexForValue(double value, bool smaller) const;
 	double valueLabelsValueAt(int index) const;
 	QString valueLabelAt(int index) const;
 	void addValueLabel(qint64, const QString&);
@@ -251,6 +253,8 @@ public:
 	void addValueLabel(const QString&, const QString&);
 	const QVector<Column::ValueLabel<QString>>* textValueLabels() const;
 
+	Column* const q{nullptr};
+
 private:
 	AbstractColumn::ColumnMode m_columnMode; // type of column data
 	void* m_data{nullptr}; // pointer to the data container (QVector<T>)
@@ -262,12 +266,11 @@ private:
 	AbstractSimpleFilter* m_outputFilter{nullptr}; // output filter for data type -> string conversion
 	QString m_formula;
 	QVector<Column::FormulaData> m_formulaData;
-	bool m_formulaAutoUpdate{false};
+	bool m_formulaAutoUpdate{true};
 	bool m_formulaAutoResize{true};
 	IntervalAttribute<QString> m_formulas;
 	AbstractColumn::PlotDesignation m_plotDesignation{AbstractColumn::PlotDesignation::NoDesignation};
 	int m_width{0}; // column width in the view
-	Column* m_owner{nullptr};
 	QVector<QMetaObject::Connection> m_connectionsUpdateFormula;
 
 	void initDictionary();
@@ -286,13 +289,13 @@ private:
 
 		invalidate();
 
-		Q_EMIT m_owner->dataAboutToChange(m_owner);
+		Q_EMIT q->dataAboutToChange(q);
 		if (row >= rowCount())
 			resizeTo(row + 1);
 
 		static_cast<QVector<T>*>(m_data)->replace(row, new_value);
-		if (!m_owner->m_suppressDataChangedSignal)
-			Q_EMIT m_owner->dataChanged(m_owner);
+		if (!m_suppressDataChangedSignal)
+			Q_EMIT q->dataChanged(q);
 	}
 
 	// Never call this function directly, because it does no
@@ -307,7 +310,7 @@ private:
 
 		invalidate();
 
-		Q_EMIT m_owner->dataAboutToChange(m_owner);
+		Q_EMIT q->dataAboutToChange(q);
 
 		if (first < 0)
 			*static_cast<QVector<T>*>(m_data) = new_values;
@@ -320,8 +323,8 @@ private:
 				ptr[first + i] = new_values.at(i);
 		}
 
-		if (!m_owner->m_suppressDataChangedSignal)
-			Q_EMIT m_owner->dataChanged(m_owner);
+		if (!m_suppressDataChangedSignal)
+			Q_EMIT q->dataChanged(q);
 	}
 
 private Q_SLOTS:
