@@ -1,11 +1,11 @@
 /*
-    File                 : DayOfWeek2IntegerFilter.h
-    Project              : AbstractColumn
-    Description          : Conversion filter QDateTime -> int, translating
-    dates into days of the week (Monday -> 1).
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2017 Stefan Gerlach <stefan.gerlach@uni.kn>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : DayOfWeek2IntegerFilter.h
+	Project              : AbstractColumn
+	Description          : Conversion filter QDateTime -> int, translating
+	dates into days of the week (Monday -> 1).
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2017 Stefan Gerlach <stefan.gerlach@uni.kn>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef DAY_OF_WEEK2INTEGER_FILTER_H
@@ -21,21 +21,24 @@ class DayOfWeek2IntegerFilter : public AbstractSimpleFilter {
 public:
 	int integerAt(int row) const override {
 		DEBUG("integerAt()");
-		if (!m_inputs.value(0)) return 0;
+		if (!m_inputs.value(0))
+			return 0;
 		QDate date = m_inputs.value(0)->dateAt(row);
-		if (!date.isValid()) return 0;
+		if (!date.isValid())
+			return 0;
 		return int(date.dayOfWeek());
 	}
 
 	//! Return the data type of the column
-	AbstractColumn::ColumnMode columnMode() const override { return AbstractColumn::ColumnMode::Integer; }
+	AbstractColumn::ColumnMode columnMode() const override {
+		return AbstractColumn::ColumnMode::Integer;
+	}
 
 protected:
 	//! Using typed ports: only date-time inputs are accepted.
-	bool inputAcceptable(int, const AbstractColumn *source) override {
+	bool inputAcceptable(int, const AbstractColumn* source) override {
 		return source->columnMode() == AbstractColumn::ColumnMode::Day;
 	}
 };
 
 #endif // ifndef DAY_OF_WEEK2INTEGER_FILTER_H
-
