@@ -15,6 +15,7 @@
 #include <QDateTime>
 #include <QStringList>
 #include <QTime>
+#include <QTimeZone>
 #include <QUndoCommand>
 
 #include <KLocalizedString>
@@ -44,22 +45,16 @@ QDateTime String2DateTimeFilter::dateTimeAt(int row) const {
 
 	// first try the selected format string m_format
 	QDateTime result = QDateTime::fromString(input_value, m_format);
-	result.setTimeSpec(Qt::UTC);
+	result.setTimeZone(QTimeZone::UTC);
 	if (result.isValid())
 		return result;
 
-		// fallback:
-		// try other format strings built from date_formats and time_formats
-		// comma and space are valid separators between date and time
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+	// fallback:
+	// try other format strings built from date_formats and time_formats
+	// comma and space are valid separators between date and time
 	QStringList strings = input_value.simplified().split(QLatin1Char(','), Qt::SkipEmptyParts);
 	if (strings.size() == 1)
 		strings = strings.at(0).split(QLatin1Char(' '), Qt::SkipEmptyParts);
-#else
-	QStringList strings = input_value.simplified().split(QLatin1Char(','), QString::SkipEmptyParts);
-	if (strings.size() == 1)
-		strings = strings.at(0).split(QLatin1Char(' '), QString::SkipEmptyParts);
-#endif
 
 	if (strings.size() < 1)
 		return result; // invalid date/time from first attempt
