@@ -39,6 +39,12 @@
 
 #include <frontend/GuiTools.h>
 
+void DatapickerImage::ReferencePoints::clearPoints() {
+	scenePos[0] = QPointF(std::nan("0"), std::nan("0"));
+	scenePos[1] = QPointF(std::nan("0"), std::nan("0"));
+	scenePos[2] = QPointF(std::nan("0"), std::nan("0"));
+}
+
 /**
  * \class DatapickerImage
  * \brief container to open image/plot.
@@ -57,6 +63,8 @@ DatapickerImage::DatapickerImage(const QString& name, bool loading)
 	, d_ptr(new DatapickerImagePrivate(this))
 	, m_segments(new Segments(this)) {
 	Q_D(DatapickerImage);
+	connect(this, &AbstractAspect::childAspectAdded, this, &DatapickerImage::childAdded);
+	connect(this, &AbstractAspect::childAspectAboutToBeRemoved, this, &DatapickerImage::childRemoved);
 	if (!loading)
 		init();
 	else {
@@ -423,6 +431,20 @@ void DatapickerImage::setPrinting(bool on) const {
 		point->setPrinting(on);
 }
 
+void DatapickerImage::clearReferencePoints() {
+	Q_D(DatapickerImage);
+	const auto& points = children<DatapickerPoint>(ChildIndexFlag::IncludeHidden);
+	if (!points.isEmpty()) {
+		beginMacro(i18n("%1: remove all axis points", name()));
+
+		for (auto* point : points)
+			point->remove();
+		endMacro();
+		d->axisPoints.clearPoints();
+		Q_EMIT axisPointsRemoved();
+	}
+}
+
 void DatapickerImage::setPlotPointsType(const PointsType pointsType) {
 	Q_D(DatapickerImage);
 	if (d->plotPointsType == pointsType)
@@ -432,14 +454,7 @@ void DatapickerImage::setPlotPointsType(const PointsType pointsType) {
 
 	if (pointsType == DatapickerImage::PointsType::AxisPoints) {
 		// clear image
-		const auto& points = children<DatapickerPoint>(ChildIndexFlag::IncludeHidden);
-		if (!points.isEmpty()) {
-			beginMacro(i18n("%1: remove all axis points", name()));
-
-			for (auto* point : points)
-				point->remove();
-			endMacro();
-		}
+		clearReferencePoints();
 		m_segments->setSegmentsVisible(false);
 	} else if (pointsType == DatapickerImage::PointsType::CurvePoints) {
 		m_segments->setSegmentsVisible(false);
@@ -476,6 +491,38 @@ void DatapickerImage::referencePointSelected(const DatapickerPoint* point) {
 	m_currentRefPoint = -1;
 }
 
+void DatapickerImage::childAdded(const AbstractAspect* child) {
+	const auto* point = dynamic_cast<const DatapickerPoint*>(child);
+	if (point) {
+		connect(point, &DatapickerPoint::dataChanged, this, &DatapickerImage::datapickerPointChanged);
+		connect(point, &DatapickerPoint::pointSelected, this, QOverload<const DatapickerPoint*>::of(&DatapickerImage::referencePointSelected));
+	}
+}
+
+void DatapickerImage::childRemoved(const AbstractAspect* child) {
+	const auto* point = dynamic_cast<const DatapickerPoint*>(child);
+	if (point)
+		disconnect(point, nullptr, this, nullptr);
+}
+
+bool DatapickerImage::addChild(AbstractAspect* child) {
+	if (dynamic_cast<DatapickerPoint*>(child) && children<DatapickerPoint>(AbstractAspect::ChildIndexFlag::IncludeHidden).count() >= 3)
+		return false;
+
+	return AbstractAspect::addChild(child);
+}
+
+void DatapickerImage::datapickerPointChanged(const DatapickerPoint* point) {
+	const auto index = indexOfChild<DatapickerPoint>(point, AbstractAspect::ChildIndexFlag::IncludeHidden);
+	assert(index < 3);
+	if (index >= 0 && index < 3) {
+		auto axisPoints = this->axisPoints();
+		axisPoints.scenePos[index].setX(point->position().x());
+		axisPoints.scenePos[index].setY(point->position().y());
+		setAxisPoints(axisPoints);
+	}
+}
+
 // ##############################################################################
 // ######################  Private implementation ###############################
 // ##############################################################################
