@@ -12,9 +12,11 @@
 #include "backend/datasources/MQTTTopic.h"
 #include "backend/datasources/filters/AsciiFilter.h"
 #include "backend/lib/XmlStreamReader.h"
-#include "kdefrontend/datasources/MQTTErrorWidget.h"
+#include "frontend/datasources/MQTTErrorWidget.h"
 
 #include <QTimer>
+#include <QtMqtt/QMqttSubscription>
+#include <QtMqtt/QMqttTopicName>
 
 /*!
   \class MQTTClient
@@ -28,13 +30,11 @@ MQTTClient::MQTTClient(const QString& name)
 	, m_updateTimer(new QTimer(this))
 	, m_client(new QMqttClient(this))
 	, m_willTimer(new QTimer(this)) {
-	// stop reading from the source before removing the child from the project
-	connect(this, &AbstractAspect::childAspectAboutToBeRemoved, this, &MQTTClient::pauseReading);
-
 	connect(m_updateTimer, &QTimer::timeout, this, &MQTTClient::read);
 	connect(m_client, &QMqttClient::connected, this, &MQTTClient::onMQTTConnect);
 	connect(m_willTimer, &QTimer::timeout, this, &MQTTClient::updateWillMessage);
 	connect(m_client, &QMqttClient::errorChanged, this, &MQTTClient::MQTTErrorChanged);
+	connect(m_client, &QMqttClient::disconnected, this, &MQTTClient::disconnected);
 }
 
 MQTTClient::~MQTTClient() {
@@ -93,6 +93,9 @@ void MQTTClient::pauseReading() {
  */
 void MQTTClient::setFilter(AsciiFilter* f) {
 	delete m_filter;
+	auto* asciiFilter = dynamic_cast<AsciiFilter*>(f);
+	if (asciiFilter)
+		asciiFilter->setDataSource(nullptr); // MQTTClient does not have a dataSource
 	m_filter = f;
 }
 
@@ -351,11 +354,9 @@ QVector<QString> MQTTClient::MQTTSubscriptions() const {
 void MQTTClient::addMQTTSubscription(const QString& topicName, quint8 QoS) {
 	// Check whether the subscription already exists, if it doesn't, we can add it
 	if (!m_subscriptions.contains(topicName)) {
-		const QMqttTopicFilter filter{topicName};
-		QMqttSubscription* temp = m_client->subscribe(filter, QoS);
-
+		const auto* temp = m_client->subscribe(QMqttTopicFilter(topicName), QoS);
 		if (temp) {
-			// 			qDebug()<<"Subscribe to: "<< temp->topic() << "  " << temp->qos();
+			// qDebug()<<"Subscribe to: "<< temp->topic() << "  " << temp->qos();
 			m_subscriptions.push_back(temp->topic().filter());
 			m_subscribedTopicNameQoS[temp->topic().filter()] = temp->qos();
 
@@ -378,20 +379,16 @@ void MQTTClient::addMQTTSubscription(const QString& topicName, quint8 QoS) {
 			// If there are some inferior subscriptions, we have to deal with them
 			if (found) {
 				for (auto* inferiorSubscription : inferiorSubscriptions) {
-					// 					qDebug()<<"Reparent topics of inferior subscription: "<< inferiorSubscription->subscriptionName();
-
+					// qDebug()<<"Reparent topics of inferior subscription: "<< inferiorSubscription->subscriptionName();
 					// We have to reparent every topic of the inferior subscription, so no data is lost
-					QVector<MQTTTopic*> topics = inferiorSubscription->topics();
-					for (auto* topic : topics) {
+					const auto& topics = inferiorSubscription->topics();
+					for (auto* topic : topics)
 						topic->reparent(newSubscription);
-					}
 
 					// Then remove the subscription and every connected information
-					QMqttTopicFilter unsubscribeFilter{inferiorSubscription->subscriptionName()};
-					m_client->unsubscribe(unsubscribeFilter);
-
+					m_client->unsubscribe(QMqttTopicFilter(inferiorSubscription->subscriptionName()));
 					for (int j = 0; j < m_MQTTSubscriptions.size(); ++j) {
-						if (m_MQTTSubscriptions[j]->subscriptionName() == inferiorSubscription->subscriptionName()) {
+						if (m_MQTTSubscriptions.at(j)->subscriptionName() == inferiorSubscription->subscriptionName()) {
 							m_MQTTSubscriptions.remove(j);
 						}
 					}
@@ -403,7 +400,6 @@ void MQTTClient::addMQTTSubscription(const QString& topicName, quint8 QoS) {
 			}
 
 			connect(temp, &QMqttSubscription::messageReceived, this, &MQTTClient::MQTTSubscriptionMessageReceived);
-
 			Q_EMIT MQTTTopicsChanged();
 		}
 	}
@@ -420,17 +416,18 @@ void MQTTClient::removeMQTTSubscription(const QString& subscriptionName) {
 		// unsubscribe from the topic
 		const QMqttTopicFilter filter{subscriptionName};
 		m_client->unsubscribe(filter);
-		// 		qDebug()<<"Unsubscribe from: " << subscriptionName;
+		// qDebug()<<"Unsubscribe from: " << subscriptionName;
 
 		// Remove every connected information
 		m_subscriptions.removeAll(subscriptionName);
 
 		for (int i = 0; i < m_MQTTSubscriptions.size(); ++i) {
-			if (m_MQTTSubscriptions[i]->subscriptionName() == subscriptionName) {
-				MQTTSubscription* removeSubscription = m_MQTTSubscriptions[i];
+			if (m_MQTTSubscriptions.at(i)->subscriptionName() == subscriptionName) {
+				auto* removeSubscription = m_MQTTSubscriptions.at(i);
 				m_MQTTSubscriptions.remove(i);
+
 				// Remove every topic of the subscription as well
-				QVector<MQTTTopic*> topics = removeSubscription->topics();
+				const auto& topics = removeSubscription->topics();
 				for (const auto& topic : topics)
 					m_topicNames.removeAll(topic->topicName());
 
@@ -463,11 +460,11 @@ void MQTTClient::addBeforeRemoveSubscription(const QString& topicName, quint8 Qo
 	// We can't add the subscription if it already exists
 	if (!m_subscriptions.contains(topicName)) {
 		// Subscribe to the topic
-		QMqttTopicFilter filter{topicName};
-		QMqttSubscription* temp = m_client->subscribe(filter, QoS);
+		const QMqttTopicFilter filter{topicName};
+		auto* temp = m_client->subscribe(filter, QoS);
 		if (temp) {
 			// Add the MQTTSubscription and other connected data
-			// 			qDebug()<<"Add subscription before remove: " << temp->topic() << "  " << temp->qos();
+			// qDebug()<<"Add subscription before remove: " << temp->topic() << "  " << temp->qos();
 			m_subscriptions.push_back(temp->topic().filter());
 			m_subscribedTopicNameQoS[temp->topic().filter()] = temp->qos();
 
@@ -520,7 +517,7 @@ void MQTTClient::addBeforeRemoveSubscription(const QString& topicName, quint8 Qo
 void MQTTClient::reparentTopic(const QString& topicName, const QString& parentTopicName) {
 	// We can only reparent if the parent contained the topic
 	if (m_subscriptions.contains(parentTopicName) && m_topicNames.contains(topicName)) {
-		// 		qDebug() << "Reparent " << topicName << " to " << parentTopicName;
+		// qDebug() << "Reparent " << topicName << " to " << parentTopicName;
 		// search for the parent MQTTSubscription
 		bool found = false;
 		MQTTSubscription* superiorSubscription = nullptr;
@@ -560,13 +557,8 @@ bool MQTTClient::checkTopicContains(const QString& superior, const QString& infe
 		return true;
 	else {
 		if (superior.contains(QLatin1String("/"))) {
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
 			QStringList superiorList = superior.split(QLatin1Char('/'), Qt::SkipEmptyParts);
 			QStringList inferiorList = inferior.split(QLatin1Char('/'), Qt::SkipEmptyParts);
-#else
-			QStringList superiorList = superior.split(QLatin1Char('/'), QString::SkipEmptyParts);
-			QStringList inferiorList = inferior.split(QLatin1Char('/'), QString::SkipEmptyParts);
-#endif
 
 			// a longer topic can't contain a shorter one
 			if (superiorList.size() > inferiorList.size())
@@ -603,13 +595,8 @@ bool MQTTClient::checkTopicContains(const QString& superior, const QString& infe
  * \return The name of the common topic, if it exists, otherwise an empty string
  */
 QString MQTTClient::checkCommonLevel(const QString& first, const QString& second) {
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
 	QStringList firstList = first.split(QLatin1Char('/'), Qt::SkipEmptyParts);
 	QStringList secondtList = second.split(QLatin1Char('/'), Qt::SkipEmptyParts);
-#else
-	QStringList firstList = first.split(QLatin1Char('/'), QString::SkipEmptyParts);
-	QStringList secondtList = second.split(QLatin1Char('/'), QString::SkipEmptyParts);
-#endif
 	QString commonTopic;
 
 	if (!firstList.isEmpty()) {
@@ -651,7 +638,7 @@ QString MQTTClient::checkCommonLevel(const QString& first, const QString& second
 			}
 		}
 	}
-	// 	qDebug() << first << " " << second << " common topic: "<<commonTopic;
+	// qDebug() << first << " " << second << " common topic: "<<commonTopic;
 	return commonTopic;
 }
 
@@ -766,10 +753,9 @@ QString MQTTClient::willOwnMessage() const {
  * \brief Updates the will message of the client
  */
 void MQTTClient::updateWillMessage() {
-	QVector<const MQTTTopic*> topics = children<const MQTTTopic>(AbstractAspect::ChildIndexFlag::Recursive);
-	const MQTTTopic* willTopic = nullptr;
-
 	// Search for the will topic
+	const auto& topics = children<const MQTTTopic>(AbstractAspect::ChildIndexFlag::Recursive);
+	const MQTTTopic* willTopic = nullptr;
 	for (const auto* topic : topics) {
 		if (topic->topicName() == m_MQTTWill.willTopic) {
 			willTopic = topic;
@@ -812,12 +798,12 @@ void MQTTClient::updateWillMessage() {
 					m_client->setWillMessage(this->statistics(willTopic).toUtf8());
 				else
 					m_client->setWillMessage(QByteArray()); // empty message
-				// 					qDebug() << "Will statistics message: "<< QString(m_client->willMessage());
+				// qDebug() << "Will statistics message: "<< QString(m_client->willMessage());
 				break;
 			}
 			case WillMessageType::LastMessage:
 				m_client->setWillMessage(m_MQTTWill.willLastMessage.toUtf8());
-				// 				qDebug()<<"Will last message:\n" << m_MQTTWill.willLastMessage;
+				// qDebug()<<"Will last message:\n" << m_MQTTWill.willLastMessage;
 				break;
 			default:
 				break;
@@ -825,7 +811,7 @@ void MQTTClient::updateWillMessage() {
 			m_disconnectForWill = false;
 			// Reconnect with the updated message
 			m_client->connectToHost();
-			// 			qDebug()<< "Reconnect to host after updating will message";
+			// qDebug()<< "Reconnect to host after updating will message";
 		}
 	}
 }
@@ -993,14 +979,14 @@ void MQTTClient::read() {
 		return;
 
 	if (!m_prepared) {
-		// 		qDebug()<<"Connect";
+		// qDebug()<<"Connect";
 		// connect to the broker
 		m_client->connectToHost();
 		m_prepared = true;
 	}
 
 	if ((m_client->state() == QMqttClient::ClientState::Connected) && m_MQTTFirstConnectEstablished) {
-		// 		qDebug()<<"Read";
+		// qDebug()<<"Read";
 		// Signal for every MQTTTopic that they can read
 		Q_EMIT readFromTopics();
 	}
@@ -1013,14 +999,13 @@ void MQTTClient::onMQTTConnect() {
 	if (m_client->error() == QMqttClient::NoError) {
 		// if this is the first connection (after setting the options in ImportFileWidget or loading saved project)
 		if (!m_MQTTFirstConnectEstablished) {
-			// 			qDebug()<<"connection made in MQTTClient";
+			// qDebug()<<"connection made in MQTTClient";
 
 			// Subscribe to initial or loaded topics
 			QMapIterator<QMqttTopicFilter, quint8> i(m_subscribedTopicNameQoS);
 			while (i.hasNext()) {
 				i.next();
-				// 				qDebug()<<i.key();
-				QMqttSubscription* temp = m_client->subscribe(i.key(), i.value());
+				const auto* temp = m_client->subscribe(i.key(), i.value());
 				if (temp) {
 					// If we didn't load the MQTTClient from xml we have to add the MQTTSubscriptions
 					if (!m_loaded) {
@@ -1038,23 +1023,20 @@ void MQTTClient::onMQTTConnect() {
 				}
 			}
 			m_MQTTFirstConnectEstablished = true;
-			// Signal that the initial subscriptions were made
-			Q_EMIT MQTTSubscribed();
-		}
-		// if there was already a connection made(happens after updating will message)
-		else {
-			// 			qDebug() << "Start resubscribing after will message update";
+			Q_EMIT MQTTSubscribed(); // notify about the initial subscriptiong made
+		} else { // connection already available, happens after updating will message
+			// qDebug() << "Start resubscribing after will message update";
 			// Only the client has to make the subscriptions again, every other connected data is still available
 			QMapIterator<QMqttTopicFilter, quint8> i(m_subscribedTopicNameQoS);
 			while (i.hasNext()) {
 				i.next();
-				QMqttSubscription* temp = m_client->subscribe(i.key(), i.value());
+				const auto* temp = m_client->subscribe(i.key(), i.value());
 				if (temp) {
-					// 					qDebug()<<temp->topic()<<"  "<<temp->qos();
+					// qDebug()<<temp->topic()<<"  "<<temp->qos();
 					connect(temp, &QMqttSubscription::messageReceived, this, &MQTTClient::MQTTSubscriptionMessageReceived);
 				}
-				// 				else
-				// 					qDebug()<<"Couldn't subscribe after will update";
+				// else
+				// qDebug()<<"Couldn't subscribe after will update";
 			}
 		}
 	}
@@ -1074,7 +1056,8 @@ void MQTTClient::MQTTSubscriptionMessageReceived(const QMqttMessage& msg) {
 		// Pass the message and the topic name to the MQTTSubscription which contains the topic
 		for (auto* subscription : m_MQTTSubscriptions) {
 			if (checkTopicContains(subscription->subscriptionName(), msg.topic().name())) {
-				subscription->messageArrived(QLatin1String(msg.payload()), msg.topic().name());
+				subscription->messageArrived(msg);
+				Q_EMIT messagedReceived();
 				break;
 			}
 		}
@@ -1082,7 +1065,6 @@ void MQTTClient::MQTTSubscriptionMessageReceived(const QMqttMessage& msg) {
 		// if the message was received by the will topic, update the last message received by it
 		if (msg.topic().name() == m_MQTTWill.willTopic) {
 			m_MQTTWill.willLastMessage = QLatin1String(msg.payload());
-
 			Q_EMIT MQTTTopicsChanged();
 		}
 	}
@@ -1098,6 +1080,14 @@ void MQTTClient::MQTTErrorChanged(QMqttClient::ClientError clientError) {
 	}
 }
 
+void MQTTClient::disconnected() {
+	auto error = m_client->error();
+	if (error != QMqttClient::ClientError::NoError) {
+		auto* errorWidget = new MQTTErrorWidget(error, this);
+		errorWidget->show();
+	}
+}
+
 /*!
  *\brief Called when a subscription is loaded.
  * Checks whether every saved subscription was loaded or not.
@@ -1107,7 +1097,7 @@ void MQTTClient::MQTTErrorChanged(QMqttClient::ClientError clientError) {
  */
 void MQTTClient::subscriptionLoaded(const QString& name) {
 	if (!name.isEmpty()) {
-		// 		qDebug() << "Finished loading: " << name;
+		// qDebug() << "Finished loading: " << name;
 		// Save information about the subscription
 		m_subscriptionsLoaded++;
 		m_subscriptions.push_back(name);
