@@ -4,7 +4,7 @@
 	Description          : file I/O-filter related interface
 	--------------------------------------------------------------------
 	SPDX-FileCopyrightText: 2009-2024 Alexander Semke <alexander.semke@web.de>
-	SPDX-FileCopyrightText: 2017-2024 Stefan Gerlach <stefan.gerlach@uni.kn>
+	SPDX-FileCopyrightText: 2017-2025 Stefan Gerlach <stefan.gerlach@uni.kn>
 
 	SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -22,14 +22,19 @@ class XmlStreamReader;
 class QXmlStreamWriter;
 class KConfig;
 
+#ifdef SDK
+#include "labplot_export.h"
+class LABPLOT_EXPORT AbstractFileFilter : public QObject {
+#else
 class AbstractFileFilter : public QObject {
+#endif
 	Q_OBJECT
-	Q_ENUMS(FileType)
-	Q_ENUMS(ImportMode)
 
 public:
-	enum class FileType { Ascii, Binary, XLSX, Ods, Image, HDF5, NETCDF, FITS, JSON, ROOT, Spice, READSTAT, MATIO, VECTOR_BLF };
+	enum class FileType { Ascii, Binary, XLSX, Ods, Image, HDF5, NETCDF, FITS, JSON, ROOT, Spice, READSTAT, MATIO, VECTOR_BLF, MCAP };
+	Q_ENUM(FileType)
 	enum class ImportMode { Append, Prepend, Replace };
+	Q_ENUM(ImportMode)
 
 	explicit AbstractFileFilter(FileType type)
 		: m_type(type) {
@@ -38,18 +43,31 @@ public:
 
 	static bool isNan(const QString&);
 	static AbstractColumn::ColumnMode columnMode(const QString& valueString, QString& dateTimeFormat, QLocale::Language);
-	static AbstractColumn::ColumnMode columnMode(const QString& valueString, QString& dateTimeFormat, const QLocale& = QLocale());
+	static AbstractColumn::ColumnMode columnMode(const QString& valueString,
+												 QString& dateTimeFormat,
+												 const QLocale& = QLocale(),
+												 bool intAsDouble = false,
+												 int baseYear = QLocale::DefaultTwoDigitBaseYear);
 	static QString dateTimeFormat(const QString& valueString);
 	static QStringList numberFormats();
+	static bool exclusiveFileType(FileType);
 	static FileType fileType(const QString&);
 	// static QStringList fileTypes();
 	static QString convertFromNumberToColumn(int n);
+	int previewPrecision() const;
+	void setPreviewPrecision(int);
 
 	virtual void readDataFromFile(const QString& fileName, AbstractDataSource* = nullptr, ImportMode = ImportMode::Replace) = 0;
+	/*!
+	 * Writing the content of the datasource to the file with filename \p fileName
+	 * \brief write
+	 * \param fileName
+	 */
 	virtual void write(const QString& fileName, AbstractDataSource*) = 0;
 
 	QString lastError() const;
 	void setLastError(const QString&);
+	void clearLastError();
 
 	QStringList lastWarnings() const;
 	void addWarning(const QString&);
@@ -70,6 +88,7 @@ protected:
 	const FileType m_type;
 	QString m_lastError;
 	QStringList m_lastWarnings;
+	int m_previewPrecision{6};
 };
 
 #endif
