@@ -4,6 +4,7 @@
 	Description          : FITS I/O-filter
 	--------------------------------------------------------------------
 	SPDX-FileCopyrightText: 2016 Fabian Kristof <fkristofszabolcs@gmail.com>
+	SPDX-FileCopyrightText: 2025 Stefan Gerlach <stefan.gerlach@uni.kn>
 	SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef FITSFILTER_H
@@ -27,12 +28,21 @@ public:
 	FITSFilter();
 	~FITSFilter() override;
 
+	static QString fileInfoString(const QString&);
+	static QStringList standardKeywords();
+	static QStringList mandatoryImageExtensionKeywords();
+	static QStringList mandatoryTableExtensionKeywords();
+	static QStringList units();
+
 	void readDataFromFile(const QString& fileName, AbstractDataSource* = nullptr, ImportMode = ImportMode::Replace) override;
 	void write(const QString& fileName, AbstractDataSource*) override;
 	QVector<QStringList> readChdu(const QString& fileName, bool* okToMatrix = nullptr, int lines = -1);
 	void save(QXmlStreamWriter*) const override;
 	bool load(XmlStreamReader*) override;
 
+	void setCurrentExtensionName(const QString&);
+	const QString currentExtensionName() const;
+
 	struct KeywordUpdate {
 		KeywordUpdate()
 			: keyUpdated(false)
@@ -68,7 +78,6 @@ public:
 		KeywordUpdate updates;
 	};
 
-	static QString fileInfoString(const QString&);
 	void updateKeywords(const QString& fileName, const QList<Keyword>& originals, const QVector<Keyword>& updates);
 	void addNewKeyword(const QString& filename, const QList<Keyword>& keywords);
 	void addKeywordUnit(const QString& fileName, const QList<Keyword>& keywords);
@@ -78,11 +87,6 @@ public:
 	void parseExtensions(const QString& fileName, QTreeWidget* tw, bool checkPrimary = false);
 	QList<Keyword> chduKeywords(const QString& fileName);
 
-	static QStringList standardKeywords();
-	static QStringList mandatoryImageExtensionKeywords();
-	static QStringList mandatoryTableExtensionKeywords();
-	static QStringList units();
-
 	void setStartRow(const int);
 	int startRow() const;
 	void setEndRow(const int);
