@@ -39,7 +39,7 @@ QStringList ImageFilter::importFormats() {
 /*!
   reads the content of the file \c fileName to the data source \c dataSource.
 */
-void ImageFilter::readDataFromFile(const QString& fileName, AbstractDataSource* dataSource, AbstractFileFilter::ImportMode importMode) {
+void ImageFilter::readDataFromFile(const QString& fileName, AbstractDataSource* dataSource, ImportMode importMode) {
 	d->readDataFromFile(fileName, dataSource, importMode);
 }
 
@@ -51,19 +51,6 @@ void ImageFilter::write(const QString& fileName, AbstractDataSource* dataSource)
 	// 	emit()
 }
 
-///////////////////////////////////////////////////////////////////////
-/*!
-  loads the predefined filter settings for \c filterName
-*/
-void ImageFilter::loadFilterSettings(const QString& /*filterName*/) {
-}
-
-/*!
-  saves the current settings as a new filter with the name \c filterName
-*/
-void ImageFilter::saveFilterSettings(const QString& /*filterName*/) const {
-}
-
 ///////////////////////////////////////////////////////////////////////
 void ImageFilter::setImportFormat(const ImageFilter::ImportFormat f) {
 	d->importFormat = f;
@@ -113,9 +100,9 @@ QString ImageFilter::fileInfoString(const QString& /*fileName*/) {
 	return info;
 }
 
-//#####################################################################
-//################### Private implementation ##########################
-//#####################################################################
+// #####################################################################
+// ################### Private implementation ##########################
+// #####################################################################
 
 ImageFilterPrivate::ImageFilterPrivate(ImageFilter* owner)
 	: q(owner) {
@@ -128,9 +115,7 @@ ImageFilterPrivate::ImageFilterPrivate(ImageFilter* owner)
 void ImageFilterPrivate::readDataFromFile(const QString& fileName, AbstractDataSource* dataSource, AbstractFileFilter::ImportMode mode) {
 	QImage image = QImage(fileName);
 	if (image.isNull() || image.format() == QImage::Format_Invalid) {
-#ifdef QT_DEBUG
-		qDebug() << "failed to read image" << fileName << "or invalid image format";
-#endif
+		q->setLastError(i18n("Empty file or invalid or non-supported format."));
 		return;
 	}
 
@@ -173,9 +158,14 @@ void ImageFilterPrivate::readDataFromFile(const QString& fileName, AbstractDataS
 	// TODO: use given names?
 	QStringList vectorNames;
 
-	if (dataSource)
-		columnOffset = dataSource->prepareImport(dataContainer, mode, actualRows, actualCols, vectorNames, columnModes);
-	else {
+	if (dataSource) {
+		bool ok = false;
+		columnOffset = dataSource->prepareImport(dataContainer, mode, actualRows, actualCols, vectorNames, columnModes, ok);
+		if (!ok) {
+			q->setLastError(i18n("Not enough memory."));
+			return;
+		}
+	} else {
 		DEBUG("data source in image import not defined! Giving up.");
 		return;
 	}
@@ -249,9 +239,9 @@ void ImageFilterPrivate::write(const QString& /*fileName*/, AbstractDataSource*
 	// TODO
 }
 
-//##############################################################################
-//##################  Serialization/Deserialization  ###########################
-//##############################################################################
+// ##############################################################################
+// ##################  Serialization/Deserialization  ###########################
+// ##############################################################################
 
 /*!
   Saves as XML.
@@ -265,8 +255,5 @@ void ImageFilter::save(QXmlStreamWriter* writer) const {
   Loads from XML.
 */
 bool ImageFilter::load(XmlStreamReader*) {
-	// 	KLocalizedString attributeWarning = ki18n("Attribute '%1' missing or empty, default value is used");
-	// 	QXmlStreamAttributes attribs = reader->attributes();
-
 	return true;
 }
