@@ -13,12 +13,17 @@
 
 class ImageFilterPrivate;
 
+#ifdef SDK
+#include "labplot_export.h"
+class LABPLOT_EXPORT ImageFilter : public AbstractFileFilter {
+#else
 class ImageFilter : public AbstractFileFilter {
+#endif
 	Q_OBJECT
-	Q_ENUMS(ImportFormat)
 
 public:
 	enum class ImportFormat { MATRIX, XYZ, XYRGB };
+	Q_ENUM(ImportFormat)
 
 	ImageFilter();
 	~ImageFilter() override;
