@@ -11,11 +11,13 @@
 #include "NetCDFFilterPrivate.h"
 #include "backend/core/column/Column.h"
 #include "backend/lib/XmlStreamReader.h"
+#include "backend/lib/hostprocess.h"
 #include "backend/lib/macros.h"
 #include "backend/spreadsheet/Spreadsheet.h"
 
 #include <KLocalizedString>
 #include <QProcess>
+#include <QStandardPaths>
 
 ///////////// macros ///////////////////////////////////////////////
 
@@ -137,15 +139,14 @@ QString NetCDFFilter::readAttribute(const QString& fileName, const QString& name
 /*!
   reads the content of the current variable from file \c fileName.
 */
-QVector<QStringList>
-NetCDFFilter::readCurrentVar(const QString& fileName, AbstractDataSource* dataSource, AbstractFileFilter::ImportMode importMode, int lines) {
+QVector<QStringList> NetCDFFilter::readCurrentVar(const QString& fileName, AbstractDataSource* dataSource, ImportMode importMode, int lines) {
 	return d->readCurrentVar(fileName, dataSource, importMode, lines);
 }
 
 /*!
   reads the content of the file \c fileName to the data source \c dataSource.
 */
-void NetCDFFilter::readDataFromFile(const QString& fileName, AbstractDataSource* dataSource, AbstractFileFilter::ImportMode mode) {
+void NetCDFFilter::readDataFromFile(const QString& fileName, AbstractDataSource* dataSource, ImportMode mode) {
 	d->readDataFromFile(fileName, dataSource, mode);
 }
 
@@ -157,19 +158,6 @@ void NetCDFFilter::write(const QString& fileName, AbstractDataSource* dataSource
 	// 	emit()
 }
 
-///////////////////////////////////////////////////////////////////////
-/*!
-  loads the predefined filter settings for \c filterName
-*/
-void NetCDFFilter::loadFilterSettings(const QString& /*filterName*/) {
-}
-
-/*!
-  saves the current settings as a new filter with the name \c filterName
-*/
-void NetCDFFilter::saveFilterSettings(const QString& /*filterName*/) const {
-}
-
 ///////////////////////////////////////////////////////////////////////
 
 void NetCDFFilter::setCurrentVarName(const QString& ds) {
@@ -267,14 +255,14 @@ QString NetCDFFilter::fileCDLString(const QString& fileName) {
 
 	QString CDLString;
 #ifdef Q_OS_LINUX
-	const QString ncdumpFullPath = QStandardPaths::findExecutable(QLatin1String("ncdump"));
+	const QString ncdumpFullPath = safeExecutableName(QStringLiteral("ncdump"));
 	if (ncdumpFullPath.isEmpty())
 		return i18n("ncdump not found.");
 
 	QProcess proc;
 	QStringList args;
 	args << QStringLiteral("-cs") << fileName;
-	proc.start(ncdumpFullPath, args);
+	startHostProcess(proc, ncdumpFullPath, args);
 
 	if (proc.waitForReadyRead(1000) == false)
 		CDLString += i18n("Reading from file %1 failed.", fileName);
@@ -291,9 +279,9 @@ QString NetCDFFilter::fileCDLString(const QString& fileName) {
 	return CDLString;
 }
 
-//#####################################################################
-//################### Private implementation ##########################
-//#####################################################################
+// #####################################################################
+// ################### Private implementation ##########################
+// #####################################################################
 
 NetCDFFilterPrivate::NetCDFFilterPrivate(NetCDFFilter* owner)
 	: q(owner) {
@@ -307,6 +295,7 @@ void NetCDFFilterPrivate::handleError(int err, const QString& function) {
 	Q_UNUSED(function);
 	if (err != NC_NOERR) {
 		DEBUG("NETCDF ERROR:" << STDSTRING(function) << "() - " << nc_strerror(err));
+		// TODO q->setLastError(i18n("NetCDF Error: %1() - %2", function, nc_strerror(err)));
 		return;
 	}
 }
@@ -696,21 +685,20 @@ QString NetCDFFilterPrivate::readAttribute(const QString& fileName, const QStrin
 */
 QVector<QStringList>
 NetCDFFilterPrivate::readCurrentVar(const QString& fileName, AbstractDataSource* dataSource, AbstractFileFilter::ImportMode mode, int lines) {
-	QVector<QStringList> dataStrings;
-
 	if (currentVarName.isEmpty()) {
-		DEBUG(Q_FUNC_INFO << ", WARNING: current var name is empty!")
-		return dataStrings << (QStringList() << i18n("No variable selected"));
+		q->setLastError(i18n("No variable selected."));
+		return {};
 	}
 	DEBUG(" current variable = " << STDSTRING(currentVarName));
 
+	QVector<QStringList> dataStrings;
 #ifdef HAVE_NETCDF
 	int ncid;
 	m_status = nc_open(qPrintable(fileName), NC_NOWRITE, &ncid);
 	handleError(m_status, QStringLiteral("nc_open"));
 	if (m_status != NC_NOERR) {
-		DEBUG("	Giving up");
-		return dataStrings;
+		q->setLastError(i18n("Failed to open the file or it's empty."));
+		return {};
 	}
 
 	int varid;
@@ -763,8 +751,14 @@ NetCDFFilterPrivate::readCurrentVar(const QString& fileName, AbstractDataSource*
 		// TODO: use given names?
 		QStringList vectorNames;
 
-		if (dataSource)
-			columnOffset = dataSource->prepareImport(dataContainer, mode, actualRows, actualCols, vectorNames, columnModes);
+		if (dataSource) {
+			bool ok = false;
+			columnOffset = dataSource->prepareImport(dataContainer, mode, actualRows, actualCols, vectorNames, columnModes, ok);
+			if (!ok) {
+				q->setLastError(i18n("Not enough memory."));
+				return QVector<QStringList>();
+			}
+		}
 
 		DEBUG("	Reading data of type " << STDSTRING(translateDataType(type)));
 		switch (type) {
@@ -868,8 +862,14 @@ NetCDFFilterPrivate::readCurrentVar(const QString& fileName, AbstractDataSource*
 		// TODO: use given names?
 		QStringList vectorNames;
 
-		if (dataSource)
-			columnOffset = dataSource->prepareImport(dataContainer, mode, actualRows, actualCols, vectorNames, columnModes);
+		if (dataSource) {
+			bool ok = false;
+			columnOffset = dataSource->prepareImport(dataContainer, mode, actualRows, actualCols, vectorNames, columnModes, ok);
+			if (!ok) {
+				q->setLastError(i18n("Not enough memory."));
+				return QVector<QStringList>();
+			}
+		}
 
 		DEBUG("	Reading data of type " << STDSTRING(translateDataType(type)));
 		switch (type) {
@@ -935,6 +935,7 @@ NetCDFFilterPrivate::readCurrentVar(const QString& fileName, AbstractDataSource*
 		// TODO: NC_STRING
 		default:
 			DEBUG("	data type not supported yet");
+			q->setLastError(i18n("Data type not supported yet."));
 		}
 
 		break;
@@ -993,8 +994,14 @@ NetCDFFilterPrivate::readCurrentVar(const QString& fileName, AbstractDataSource*
 		// TODO: use given names?
 		QStringList vectorNames;
 
-		if (dataSource)
-			columnOffset = dataSource->prepareImport(dataContainer, mode, actualRows, actualCols, vectorNames, columnModes);
+		if (dataSource) {
+			bool ok = false;
+			columnOffset = dataSource->prepareImport(dataContainer, mode, actualRows, actualCols, vectorNames, columnModes, ok);
+			if (!ok) {
+				q->setLastError(i18n("Not enough memory."));
+				return QVector<QStringList>();
+			}
+		}
 
 		switch (type) {
 		case NC_BYTE: {
@@ -1068,12 +1075,12 @@ NetCDFFilterPrivate::readCurrentVar(const QString& fileName, AbstractDataSource*
 		// TODO: NC_STRING
 		default:
 			DEBUG("	data type not supported yet");
+			q->setLastError(i18n("Data type not supported yet."));
 		}
 		break;
 	}
 	default:
-		dataStrings << (QStringList() << i18n("%1 dimensional data of type %2 not supported yet", ndims, translateDataType(type)));
-		QDEBUG(dataStrings);
+		q->setLastError(i18n("%1 dimensional data of type %2 not supported yet", ndims, translateDataType(type)));
 	}
 
 	free(dimids);
@@ -1104,6 +1111,7 @@ QVector<QStringList> NetCDFFilterPrivate::readDataFromFile(const QString& fileNa
 
 	if (currentVarName.isEmpty()) {
 		DEBUG(Q_FUNC_INFO << ", no variable selected");
+		q->setLastError(i18n("No variable selected."));
 		return dataStrings;
 	}
 
@@ -1117,9 +1125,9 @@ void NetCDFFilterPrivate::write(const QString& /*fileName*/, AbstractDataSource*
 	// TODO: writing NetCDF files not implemented yet
 }
 
-//##############################################################################
-//##################  Serialization/Deserialization  ###########################
-//##############################################################################
+// ##############################################################################
+// ##################  Serialization/Deserialization  ###########################
+// ##############################################################################
 
 /*!
   Saves as XML.
@@ -1133,7 +1141,5 @@ void NetCDFFilter::save(QXmlStreamWriter* writer) const {
   Loads from XML.
 */
 bool NetCDFFilter::load(XmlStreamReader*) {
-	// 	KLocalizedString attributeWarning = ki18n("Attribute '%1' missing or empty, default value is used");
-	// 	QXmlStreamAttributes attribs = reader->attributes();
 	return true;
 }
