@@ -17,7 +17,12 @@ class ROOTFilterPrivate;
 class QIODevice;
 
 /// Manages the importing of histograms from ROOT files
+#ifdef SDK
+#include "labplot_export.h"
+class LABPLOT_EXPORT ROOTFilter : public AbstractFileFilter {
+#else
 class ROOTFilter : public AbstractFileFilter {
+#endif
 	Q_OBJECT
 
 public:
