@@ -3,7 +3,7 @@
 	Project              : LabPlot
 	Description          : base class for project parsers
 	--------------------------------------------------------------------
-	SPDX-FileCopyrightText: 2017 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2017-2024 Alexander Semke <alexander.semke@web.de>
 	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -12,10 +12,10 @@
 
 #include <QObject>
 
-class QAbstractItemModel;
-class QString;
 class Folder;
 class Project;
+class QAbstractItemModel;
+class QString;
 
 enum class AspectType : quint64;
 
@@ -38,7 +38,7 @@ protected:
 	virtual bool load(Project*, bool preview) = 0;
 
 	QString m_projectFileName;
-	Project* m_project{nullptr};
+	Project* m_previewProject{nullptr};
 	QList<AspectType> m_topLevelClasses;
 
 private:
