@@ -10,7 +10,6 @@
 #ifndef IMAGE_H
 #define IMAGE_H
 
-#include "backend/lib/macros.h"
 #include "backend/worksheet/WorksheetElement.h"
 
 #include <QPen>
@@ -20,7 +19,12 @@ class ImagePrivate;
 class QBrush;
 class QFont;
 
+#ifdef SDK
+#include "labplot_export.h"
+class LABPLOT_EXPORT Image : public WorksheetElement {
+#else
 class Image : public WorksheetElement {
+#endif
 	Q_OBJECT
 
 public:
