@@ -324,10 +324,17 @@ void Worksheet::handleAspectAdded(const AbstractAspect* aspect) {
 	for (auto* child : children)
 		child->graphicsItem()->setZValue(zVal++);
 
-	// if a theme was selected in the worksheet, apply this theme for newly added children
+	// if a theme was selected in the worksheet, apply this theme for newly added children,
+	// no need to put these changes onto the undo stack, temporarily deactivate the undo awareness
+	// for the project globally so it's ignored for all elements below when applying the theme recursively.
 	if (!d->theme.isEmpty() && !isLoading() && !isPasted() && !aspect->isPasted()) {
 		KConfig config(ThemeHandler::themeFilePath(d->theme), KConfig::SimpleConfig);
+		// const_cast<WorksheetElement*>(addedElement)->setUndoAware(false, true);
+		if (project())
+			project()->setUndoAware(false);
 		const_cast<WorksheetElement*>(addedElement)->loadThemeConfig(config);
+		if (project())
+			project()->setUndoAware(true);
 	}
 
 	// recalculate the layout if enabled, set the currently added plot resizable otherwise
