@@ -3,7 +3,7 @@
 	Project              : LabPlot
 	Description          : Bar Plot
 	--------------------------------------------------------------------
-	SPDX-FileCopyrightText: 2022-2024 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2022-2025 Alexander Semke <alexander.semke@web.de>
 	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -13,7 +13,6 @@
 #include "backend/worksheet/plots/cartesian/Plot.h"
 
 class BarPlotPrivate;
-class AbstractColumn;
 class Background;
 class ErrorBar;
 class Line;
@@ -42,7 +41,7 @@ public:
 
 	// general
 	POINTER_D_ACCESSOR_DECL(const AbstractColumn, xColumn, XColumn)
-	QString& xColumnPath() const;
+	CLASS_D_ACCESSOR_DECL(QString, xColumnPath, XColumnPath)
 	BASIC_D_ACCESSOR_DECL(QVector<const AbstractColumn*>, dataColumns, DataColumns)
 	CLASS_D_ACCESSOR_DECL(QVector<QString>, dataColumnPaths, DataColumnPaths)
 	BASIC_D_ACCESSOR_DECL(BarPlot::Type, type, Type)
@@ -57,13 +56,15 @@ public:
 	void retransform() override;
 	void recalc() override;
 	void handleResize(double horizontalRatio, double verticalRatio, bool pageResize) override;
+	void updateLocale() override;
 
 	double minimum(CartesianCoordinateSystem::Dimension) const override;
 	double maximum(CartesianCoordinateSystem::Dimension) const override;
 	bool hasData() const override;
-	bool usingColumn(const Column*) const override;
+	bool usingColumn(const AbstractColumn*, bool indirect) const override;
 	void handleAspectUpdated(const QString& aspectPath, const AbstractAspect* element) override;
 	QColor color() const override;
+	QColor colorAt(int) const;
 
 	typedef BarPlotPrivate Private;
 
@@ -75,6 +76,8 @@ private:
 	void init();
 	void initActions();
 	void initMenus();
+	void connectXColumn(const AbstractColumn*);
+	void connectDataColumn(const AbstractColumn*);
 
 	QAction* orientationHorizontalAction{nullptr};
 	QAction* orientationVerticalAction{nullptr};
@@ -83,12 +86,15 @@ private:
 private Q_SLOTS:
 	// SLOTs for changes triggered via QActions in the context menu
 	void orientationChangedSlot(QAction*);
+	void xColumnAboutToBeRemoved(const AbstractAspect*);
 	void dataColumnAboutToBeRemoved(const AbstractAspect*);
 
 Q_SIGNALS:
 	// General-Tab
 	void xColumnChanged(const AbstractColumn*);
+	void xDataChanged();
 	void dataColumnsChanged(const QVector<const AbstractColumn*>&);
+	void dataDataChanged();
 	void typeChanged(BarPlot::Type);
 	void orientationChanged(BarPlot::Orientation);
 	void widthFactorChanged(double);
@@ -96,6 +102,9 @@ Q_SIGNALS:
 	// box border
 	void borderPenChanged(QPen&);
 	void borderOpacityChanged(float);
+
+	friend class BarPlotSetXColumnCmd;
+	friend class BarPlotSetDataColumnsCmd;
 };
 
 #endif
