@@ -304,14 +304,14 @@ void ErrorBarPrivate::painterPathForX(QPainterPath& path, const QVector<QPointF>
 	elines = cSystem->mapLogicalToScene(elines);
 
 	// new painter path for the error bars
-	for (const auto& line : qAsConst(elines)) {
+	for (const auto& line : std::as_const(elines)) {
 		path.moveTo(line.p1());
 		path.lineTo(line.p2());
 	}
 
 	// add caps for error bars
 	if (type == ErrorBar::Type::WithEnds) {
-		for (const auto& line : qAsConst(elines)) {
+		for (const auto& line : std::as_const(elines)) {
 			const auto& p1 = line.p1();
 			path.moveTo(QPointF(p1.x(), p1.y() - capSize / 2.));
 			path.lineTo(QPointF(p1.x(), p1.y() + capSize / 2.));
@@ -415,7 +415,7 @@ void ErrorBarPrivate::painterPathForY(QPainterPath& path,
 	elines = cSystem->mapLogicalToScene(elines);
 
 	// new painter path for the error bars
-	for (const auto& line : qAsConst(elines)) {
+	for (const auto& line : std::as_const(elines)) {
 		path.moveTo(line.p1());
 		path.lineTo(line.p2());
 	}
@@ -423,7 +423,7 @@ void ErrorBarPrivate::painterPathForY(QPainterPath& path,
 	// add caps for error bars
 	if (type == ErrorBar::Type::WithEnds) {
 		if (orientation == WorksheetElement::Orientation::Vertical) {
-			for (const auto& line : qAsConst(elines)) {
+			for (const auto& line : std::as_const(elines)) {
 				const auto& p1 = line.p1();
 				path.moveTo(QPointF(p1.x() - capSize / 2., p1.y()));
 				path.lineTo(QPointF(p1.x() + capSize / 2., p1.y()));
@@ -433,7 +433,7 @@ void ErrorBarPrivate::painterPathForY(QPainterPath& path,
 				path.lineTo(QPointF(p2.x() + capSize / 2., p2.y()));
 			}
 		} else {
-			for (const auto& line : qAsConst(elines)) {
+			for (const auto& line : std::as_const(elines)) {
 				const auto& p1 = line.p1();
 				path.moveTo(QPointF(p1.x(), p1.y() - capSize / 2.));
 				path.lineTo(QPointF(p1.x(), p1.y() + capSize / 2.));
