@@ -3,16 +3,10 @@
 	Project              : LabPlot
 	Description          : KDE Plot
 	--------------------------------------------------------------------
-	SPDX-FileCopyrightText: 2023 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2023-2024 Alexander Semke <alexander.semke@web.de>
 	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-/*!
-  \class KDEPlot
-  \brief
-
-  \ingroup worksheet
-  */
 #include "KDEPlot.h"
 #include "KDEPlotPrivate.h"
 #include "backend/core/column/Column.h"
@@ -37,6 +31,17 @@
 
 CURVE_COLUMN_CONNECT(KDEPlot, Data, data, recalc)
 
+/*!
+ * \class KDEPlot
+ * \brief This class implements the kernel density estimation plot - a visualization of the estimated probability density
+ * of one-dimensional numerical data.
+ *
+ * The estimation can be performed based on one of the supported kernels types (\sa nsl_kernel_type) and based on the
+ * different methods to define the bandwidth (\sa nsl_kde_bandwidth_type). A rug plot to visualize the provided data points
+ * can be enabled additionally to the the visualization of the curve for the estimated dencity.
+ *
+ * \ingroup CartesianPlots
+ */
 KDEPlot::KDEPlot(const QString& name)
 	: Plot(name, new KDEPlotPrivate(this), AspectType::KDEPlot) {
 	init();
@@ -98,8 +103,24 @@ void KDEPlot::init() {
 	// so we have the same name shown on the undo stack
 	connect(this, &AbstractAspect::aspectDescriptionChanged, [this] {
 		Q_D(KDEPlot);
+		d->estimationCurve->setUndoAware(false);
+		d->rugCurve->setUndoAware(false);
 		d->estimationCurve->setName(name(), AbstractAspect::NameHandling::UniqueNotRequired);
 		d->rugCurve->setName(name(), AbstractAspect::NameHandling::UniqueNotRequired);
+		d->estimationCurve->setUndoAware(true);
+		d->rugCurve->setUndoAware(true);
+	});
+
+	// propage the visual changes to the parent
+	connect(d->estimationCurve, &XYCurve::changed, this, &KDEPlot::changed);
+	connect(d->rugCurve, &XYCurve::changed, this, &KDEPlot::changed);
+
+	// synchronize the color of the data curve with the color of the rug curve (symbol color is used)
+	connect(d->estimationCurve->line(), &Line::colorChanged, [=](const QColor& color) {
+		auto* symbol = d->rugCurve->symbol();
+		symbol->setUndoAware(false);
+		symbol->setColor(color);
+		symbol->setUndoAware(true);
 	});
 }
 
@@ -182,7 +203,7 @@ bool KDEPlot::hasData() const {
 	return (d->dataColumn != nullptr);
 }
 
-bool KDEPlot::usingColumn(const Column* column) const {
+bool KDEPlot::usingColumn(const AbstractColumn* column, bool) const {
 	Q_D(const KDEPlot);
 	return (d->dataColumn == column);
 }
@@ -269,7 +290,7 @@ void KDEPlot::dataColumnAboutToBeRemoved(const AbstractAspect* aspect) {
 	Q_D(KDEPlot);
 	if (aspect == d->dataColumn) {
 		d->dataColumn = nullptr;
-		d->retransform();
+		d->recalc();
 		Q_EMIT dataChanged();
 		Q_EMIT changed();
 	}
@@ -368,7 +389,7 @@ void KDEPlotPrivate::recalc() {
 	xEstimationColumn->setValues(xData);
 	yEstimationColumn->setValues(yData);
 
-	// Q_EMIT dataChanged() in order to retransform everything with the new size/shape of the plot
+	// emit dataChanged() in order to retransform everything with the new size/shape of the plot
 	Q_EMIT q->dataChanged();
 }
 
@@ -542,16 +563,19 @@ void KDEPlot::loadThemeConfig(const KConfig& config) {
 	else
 		group = config.group(QStringLiteral("KDEPlot"));
 
-	const auto* plot = static_cast<const CartesianPlot*>(parentAspect());
+	Q_D(KDEPlot);
+	const auto* plot = d->m_plot;
 	int index = plot->curveChildIndex(this);
 	const QColor themeColor = plot->themeColorPalette(index);
 
-	Q_D(KDEPlot);
 	d->suppressRecalc = true;
 
 	d->estimationCurve->line()->loadThemeConfig(group, themeColor);
 	d->estimationCurve->background()->loadThemeConfig(group, themeColor);
+
 	d->rugCurve->symbol()->loadThemeConfig(group, themeColor);
+	d->rugCurve->line()->setStyle(Qt::NoPen);
+	d->rugCurve->symbol()->setStyle(Symbol::Style::NoSymbols);
 
 	d->suppressRecalc = false;
 	d->recalcShapeAndBoundingRect();
