@@ -143,11 +143,6 @@ void ProcessBehaviorChart::init(bool loading) {
 	d->centerLabel = new TextLabel(QStringLiteral("centerValue"));
 	d->centerLabel->setHidden(true);
 	d->centerLabel->setHorizontalAlignment(WorksheetElement::HorizontalAlignment::Left);
-	// set alpha channel to 1 (solid) for background color (default is 0 for TextLabel)
-	auto bgcolor = d->centerLabel->backgroundColor();
-	// QDEBUG(Q_FUNC_INFO << ", COLOR = " << bgcolor)
-	bgcolor.setAlphaF(1.0);
-	d->centerLabel->setBackgroundColor(bgcolor);
 
 	d->lowerLimitLabel = new TextLabel(QStringLiteral("lowerLimitValue"));
 	d->lowerLimitLabel->setHidden(true);
@@ -322,14 +317,12 @@ BASIC_SHARED_D_READER_IMPL(ProcessBehaviorChart, int, labelsPrecision, labelsPre
 QColor ProcessBehaviorChart::labelsFontColor() const {
 	Q_D(const ProcessBehaviorChart);
 	// using center label color
-	// QDEBUG(Q_FUNC_INFO << ", font color =" << d->centerLabel->fontColor())
 	return d->centerLabel->fontColor();
 }
 
 QColor ProcessBehaviorChart::labelsBackgroundColor() const {
 	Q_D(const ProcessBehaviorChart);
 	// using center label color
-	// QDEBUG(Q_FUNC_INFO << ", background color =" << d->centerLabel->backgroundColor())
 	return d->centerLabel->backgroundColor();
 }
 
@@ -338,7 +331,6 @@ QFont ProcessBehaviorChart::labelsFont() const {
 	// using center label font
 	QTextEdit te(d->centerLabel->text().text);
 	te.selectAll();
-	// QDEBUG(Q_FUNC_INFO <<", FONT =" << te.currentCharFormat().font())
 	return te.currentCharFormat().font();
 }
 
@@ -866,17 +858,23 @@ void ProcessBehaviorChartPrivate::recalc() {
 		xLowerLimitColumn->clear();
 		yLowerLimitColumn->clear();
 
-		// don't clear the labels while we're still loading and initilizing, the labels should keep their texts
+		// don't clear the labels while we're still loading and initializing, the labels should keep their texts
 		if (!q->isLoading()) {
+			centerLabel->setUndoAware(false);
+			upperLimitLabel->setUndoAware(false);
+			lowerLimitLabel->setUndoAware(false);
 			centerLabel->setText(QString());
 			upperLimitLabel->setText(QString());
 			lowerLimitLabel->setText(QString());
+			centerLabel->setUndoAware(false);
+			upperLimitLabel->setUndoAware(false);
+			lowerLimitLabel->setUndoAware(false);
 		}
 		Q_EMIT q->dataChanged();
 		Q_EMIT q->recalculated();
 
 		// notify the dock widget if the sample size is bigger than the number of rows in the data column
-		if (count == 0)
+		if (dataColumn && count == 0)
 			Q_EMIT q->statusInfo(i18n("Not enough data provided."));
 
 		return;
@@ -896,7 +894,9 @@ void ProcessBehaviorChartPrivate::recalc() {
 	for (int i = 0; i < count; ++i)
 		xColumn->setIntegerAt(i, i + 1);
 
+	dataCurve->setUndoAware(false);
 	dataCurve->setXColumn(xColumn);
+	dataCurve->setUndoAware(true);
 
 	// min and max labels for x
 	xCenterColumn->setIntegerAt(0, xMin);
@@ -969,6 +969,7 @@ void ProcessBehaviorChartPrivate::updateControlLimits() {
 	yColumn->clear();
 	yColumn->resizeTo(xColumn->rowCount());
 	Q_EMIT q->statusInfo(QString()); // reset the previous info message
+	dataCurve->setUndoAware(false);
 
 	// determine the number of labels in the source data to be taken into account
 	int count = dataColumn->rowCount();
@@ -1343,10 +1344,18 @@ void ProcessBehaviorChartPrivate::updateControlLimits() {
 				yUpperLimitColumn->setValueAt(i, maxUpperLimit);
 		}
 
-		for (int i = 0; i < yLowerLimitColumn->rowCount(); ++i) {
-			if (yLowerLimitColumn->valueAt(i) < minLowerLimit)
-				yLowerLimitColumn->setValueAt(i, minLowerLimit);
+		// show/hide the line for the lower limit depending on the chart type
+		lowerLimitCurve->setUndoAware(false);
+		if (type == ProcessBehaviorChart::Type::XmR || type == ProcessBehaviorChart::Type::XbarR || type == ProcessBehaviorChart::Type::XbarS)
+			lowerLimitCurve->setVisible(true); // lower limit line is always visible
+		else if (type == ProcessBehaviorChart::Type::mR || type == ProcessBehaviorChart::Type::R || type == ProcessBehaviorChart::Type::S
+				 || type == ProcessBehaviorChart::Type::C) {
+			if (lowerLimit == 0.)
+				lowerLimitCurve->setVisible(false);
+			else
+				lowerLimitCurve->setVisible(true);
 		}
+		lowerLimitCurve->setUndoAware(true);
 
 		upperLimitCurve->setLineType(XYCurve::LineType::MidpointHorizontal); // required for stair-step lines for P and U charts
 		lowerLimitCurve->setLineType(XYCurve::LineType::MidpointHorizontal); // required for stair-step lines for P and U charts
@@ -1362,24 +1371,9 @@ void ProcessBehaviorChartPrivate::updateControlLimits() {
 		yLowerLimitColumn->setValueAt(1, lowerLimit);
 	}
 
-	// show/hide the line for the lower limit depending on the chart type
-	lowerLimitCurve->setUndoAware(false);
-	if (type == ProcessBehaviorChart::Type::XmR || type == ProcessBehaviorChart::Type::XbarR || type == ProcessBehaviorChart::Type::XbarS)
-		lowerLimitCurve->setVisible(true); // lower limit line is always visible
-	else if (type == ProcessBehaviorChart::Type::mR || type == ProcessBehaviorChart::Type::R || type == ProcessBehaviorChart::Type::S
-			 || type == ProcessBehaviorChart::Type::C) {
-		if (lowerLimit == 0.)
-			lowerLimitCurve->setVisible(false);
-		else
-			lowerLimitCurve->setVisible(true);
-	}
-	lowerLimitCurve->setUndoAware(true);
+	dataCurve->setUndoAware(true);
 
-	yCenterColumn->setValueAt(0, center);
-	yCenterColumn->setValueAt(1, center);
-
-	// update the texts in the value labels
-	updateLabels();
+	QDEBUG(Q_FUNC_INFO << ", center: " << center << " , upper limit: " << upperLimit << ", lower limit: " << lowerLimit);
 }
 
 void ProcessBehaviorChartPrivate::updateLabels() {
@@ -1393,12 +1387,13 @@ void ProcessBehaviorChartPrivate::updateLabels() {
 
 	const bool uniformLimitLabelsAvailable = !((type == ProcessBehaviorChart::Type::P || type == ProcessBehaviorChart::Type::U) && exactLimitsEnabled);
 	const bool lowerLimitAvailable = q->lowerLimitAvailable();
+	const bool validLimits = !std::isnan(center) && !std::isnan(upperLimit) && !std::isnan(lowerLimit);
 
-	centerLabel->setVisible(labelsEnabled);
-	upperLimitLabel->setVisible(labelsEnabled && uniformLimitLabelsAvailable);
-	lowerLimitLabel->setVisible(labelsEnabled && lowerLimitAvailable && uniformLimitLabelsAvailable);
+	centerLabel->setVisible(labelsEnabled && validLimits);
+	upperLimitLabel->setVisible(labelsEnabled && validLimits && uniformLimitLabelsAvailable);
+	lowerLimitLabel->setVisible(labelsEnabled && validLimits && lowerLimitAvailable && uniformLimitLabelsAvailable);
 
-	if (labelsEnabled) {
+	if (labelsEnabled && validLimits) {
 		const auto numberLocale = QLocale();
 		if (labelsAutoPrecision) {
 			centerLabel->setText(numberLocale.toString(center));
