@@ -3,25 +3,26 @@
 	Project              : LabPlot
 	Description          : Reference range on the plot
 	--------------------------------------------------------------------
-	SPDX-FileCopyrightText: 2022 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2022-2024 Alexander Semke <alexander.semke@web.de>
 	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef REFERENCERANGE_H
 #define REFERENCERANGE_H
 
-#include <QPen>
-
-#include "backend/lib/macros.h"
 #include "backend/worksheet/WorksheetElement.h"
 
 class ReferenceRangePrivate;
-class CartesianPlot;
 class Background;
 class Line;
 class QActionGroup;
 
+#ifdef SDK
+#include "labplot_export.h"
+class LABPLOT_EXPORT ReferenceRange : public WorksheetElement {
+#else
 class ReferenceRange : public WorksheetElement {
+#endif
 	Q_OBJECT
 
 public:
