@@ -17,6 +17,7 @@
 #include "Value.h"
 #include "ValuePrivate.h"
 #include "backend/core/AbstractColumn.h"
+#include "backend/core/Project.h"
 #include "backend/lib/XmlStreamReader.h"
 #include "backend/lib/commandtemplates.h"
 
@@ -48,7 +49,7 @@ void Value::init(const KConfigGroup& group) {
 	d->suffix = group.readEntry("ValueSuffix", "");
 	auto defaultFont = QFont();
 	d->font = group.readEntry("ValueFont", QFont());
-	d->font.setPixelSize(Worksheet::convertToSceneUnits(defaultFont.pointSizeF(), Worksheet::Unit::Point));
+	d->font.setPointSizeF(Worksheet::convertToSceneUnits(defaultFont.pointSizeF(), Worksheet::Unit::Point));
 	d->color = group.readEntry("ValueColor", QColor(Qt::black));
 }
 
