@@ -19,7 +19,12 @@ extern "C" {
 
 class XYDifferentiationCurvePrivate;
 
+#ifdef SDK
+#include "labplot_export.h"
+class LABPLOT_EXPORT XYDifferentiationCurve : public XYAnalysisCurve {
+#else
 class XYDifferentiationCurve : public XYAnalysisCurve {
+#endif
 	Q_OBJECT
 
 public:
@@ -36,7 +41,6 @@ public:
 	explicit XYDifferentiationCurve(const QString& name);
 	~XYDifferentiationCurve() override;
 
-	void recalculate() override;
 	virtual const Result& result() const override;
 	QIcon icon() const override;
 	void save(QXmlStreamWriter*) const override;
