@@ -1,14 +1,13 @@
 /*
-    File                 : XYDifferentiationCurvePrivate.h
-    Project              : LabPlot
-    Description          : Private members of XYDifferentiationCurve
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2016 Stefan Gerlach <stefan.gerlach@uni.kn>
-    SPDX-FileCopyrightText: 2017 Alexander Semke <alexander.semke@web.de>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : XYDifferentiationCurvePrivate.h
+	Project              : LabPlot
+	Description          : Private members of XYDifferentiationCurve
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2016 Stefan Gerlach <stefan.gerlach@uni.kn>
+	SPDX-FileCopyrightText: 2017 Alexander Semke <alexander.semke@web.de>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #ifndef XYDIFFERENTIATIONCURVEPRIVATE_H
 #define XYDIFFERENTIATIONCURVEPRIVATE_H
 
@@ -23,7 +22,8 @@ public:
 	explicit XYDifferentiationCurvePrivate(XYDifferentiationCurve*);
 	~XYDifferentiationCurvePrivate() override;
 
-	void recalculate();
+	virtual bool recalculateSpecific(const AbstractColumn* tmpXDataColumn, const AbstractColumn* tmpYDataColumn) override;
+	virtual void resetResults() override;
 
 	XYDifferentiationCurve::DifferentiationData differentiationData;
 	XYDifferentiationCurve::DifferentiationResult differentiationResult;
