@@ -8,16 +8,8 @@
 	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-/*!
-  \class XYEquationCurve
-  \brief A xy-curve defined by a mathematical equation
-
-  \ingroup worksheet
-*/
-
 #include "XYEquationCurve.h"
 #include "XYEquationCurvePrivate.h"
-#include "backend/core/AbstractColumn.h"
 #include "backend/core/Folder.h"
 #include "backend/core/column/Column.h"
 #include "backend/gsl/ExpressionParser.h"
@@ -29,6 +21,11 @@
 #include <KLocalizedString>
 #include <QIcon>
 
+/*!
+ * \class XYEquationCurve
+ * \brief A xy-curve defined by a mathematical equation.
+ * \ingroup CartesianAnalysisPlots
+ */
 XYEquationCurve::XYEquationCurve(const QString& name)
 	: XYCurve(name, new XYEquationCurvePrivate(this), AspectType::XYEquationCurve) {
 	init();
@@ -166,23 +163,23 @@ void XYEquationCurvePrivate::recalculate() {
 			return;
 	}
 
-	ExpressionParser* parser = ExpressionParser::getInstance();
-	bool rc = false;
+	auto* parser = ExpressionParser::getInstance();
+	bool valid = false;
 	if (equationData.type == XYEquationCurve::EquationType::Cartesian) {
-		rc = parser->evaluateCartesian(equationData.expression1, equationData.min, equationData.max, equationData.count, xVector, yVector);
+		valid = parser->tryEvaluateCartesian(equationData.expression1, equationData.min, equationData.max, equationData.count, xVector, yVector);
 	} else if (equationData.type == XYEquationCurve::EquationType::Polar) {
-		rc = parser->evaluatePolar(equationData.expression1, equationData.min, equationData.max, equationData.count, xVector, yVector);
+		valid = parser->tryEvaluatePolar(equationData.expression1, equationData.min, equationData.max, equationData.count, xVector, yVector);
 	} else if (equationData.type == XYEquationCurve::EquationType::Parametric) {
-		rc = parser->evaluateParametric(equationData.expression1,
-										equationData.expression2,
-										equationData.min,
-										equationData.max,
-										equationData.count,
-										xVector,
-										yVector);
+		valid = parser->tryEvaluateParametric(equationData.expression1,
+											  equationData.expression2,
+											  equationData.min,
+											  equationData.max,
+											  equationData.count,
+											  xVector,
+											  yVector);
 	}
 
-	if (!rc) {
+	if (!valid) {
 		xVector->clear();
 		yVector->clear();
 	}
