@@ -17,7 +17,12 @@ extern "C" {
 
 class XYHilbertTransformCurvePrivate;
 
+#ifdef SDK
+#include "labplot_export.h"
+class LABPLOT_EXPORT XYHilbertTransformCurve : public XYAnalysisCurve {
+#else
 class XYHilbertTransformCurve : public XYAnalysisCurve {
+#endif
 	Q_OBJECT
 
 public:
@@ -33,7 +38,6 @@ public:
 	explicit XYHilbertTransformCurve(const QString& name);
 	~XYHilbertTransformCurve() override;
 
-	void recalculate() override;
 	virtual const XYAnalysisCurve::Result& result() const override;
 	QIcon icon() const override;
 	void save(QXmlStreamWriter*) const override;
