@@ -18,7 +18,12 @@ extern "C" {
 
 class XYIntegrationCurvePrivate;
 
+#ifdef SDK
+#include "labplot_export.h"
+class LABPLOT_EXPORT XYIntegrationCurve : public XYAnalysisCurve {
+#else
 class XYIntegrationCurve : public XYAnalysisCurve {
+#endif
 	Q_OBJECT
 
 public:
@@ -40,7 +45,6 @@ public:
 	explicit XYIntegrationCurve(const QString& name);
 	~XYIntegrationCurve() override;
 
-	void recalculate() override;
 	virtual const XYAnalysisCurve::Result& result() const override;
 	QIcon icon() const override;
 	void save(QXmlStreamWriter*) const override;
