@@ -1,13 +1,12 @@
 /*
-    File                 : XYIntegrationCurvePrivate.h
-    Project              : LabPlot
-    Description          : Private members of XYIntegrationCurve
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2016 Stefan Gerlach <stefan.gerlach@uni.kn>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : XYIntegrationCurvePrivate.h
+	Project              : LabPlot
+	Description          : Private members of XYIntegrationCurve
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2016 Stefan Gerlach <stefan.gerlach@uni.kn>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #ifndef XYINTEGRATIONCURVEPRIVATE_H
 #define XYINTEGRATIONCURVEPRIVATE_H
 
@@ -22,7 +21,8 @@ public:
 	explicit XYIntegrationCurvePrivate(XYIntegrationCurve*);
 	~XYIntegrationCurvePrivate() override;
 
-	void recalculate();
+	virtual bool recalculateSpecific(const AbstractColumn* tmpXDataColumn, const AbstractColumn* tmpYDataColumn) override;
+	virtual void resetResults() override;
 
 	XYIntegrationCurve::IntegrationData integrationData;
 	XYIntegrationCurve::IntegrationResult integrationResult;
