@@ -1,14 +1,13 @@
 /*
-    File                 : XYSmoothCurvePrivate.h
-    Project              : LabPlot
-    Description          : Private members of XYSmoothCurve
-    --------------------------------------------------------------------
-    SPDX-FileCopyrightText: 2016 Stefan Gerlach <stefan.gerlach@uni.kn>
-    SPDX-FileCopyrightText: 2017 Alexander Semke <alexander.semke@web.de>
-    SPDX-License-Identifier: GPL-2.0-or-later
+	File                 : XYSmoothCurvePrivate.h
+	Project              : LabPlot
+	Description          : Private members of XYSmoothCurve
+	--------------------------------------------------------------------
+	SPDX-FileCopyrightText: 2016 Stefan Gerlach <stefan.gerlach@uni.kn>
+	SPDX-FileCopyrightText: 2017 Alexander Semke <alexander.semke@web.de>
+	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
 #ifndef XYSMOOTHCURVEPRIVATE_H
 #define XYSMOOTHCURVEPRIVATE_H
 
@@ -23,7 +22,8 @@ public:
 	explicit XYSmoothCurvePrivate(XYSmoothCurve*);
 	~XYSmoothCurvePrivate() override;
 
-	void recalculate();
+	virtual bool recalculateSpecific(const AbstractColumn* tmpXDataColumn, const AbstractColumn* tmpYDataColumn) override;
+	virtual void resetResults() override;
 
 	XYSmoothCurve::SmoothData smoothData;
 	XYSmoothCurve::SmoothResult smoothResult;
