@@ -600,7 +600,7 @@ void DatapickerImageView::contextMenuEvent(QContextMenuEvent*) {
 // ####################################  SLOTs   ###############################
 // ##############################################################################
 void DatapickerImageView::mouseModeChanged(QAction* action) {
-	m_mouseMode = (DatapickerImageView::MouseMode)action->data().toInt();
+	const auto mode = (DatapickerImageView::MouseMode)action->data().toInt();
 
 	if (action == navigationModeAction) {
 		setInteractive(false);
@@ -616,29 +616,35 @@ void DatapickerImageView::mouseModeChanged(QAction* action) {
 		setDragMode(QGraphicsView::NoDrag);
 		m_image->setSegmentsHoverEvent(true);
 		setCursor(Qt::CrossCursor);
-
 		if (currentPlotPointsTypeAction != action) {
-			if (action == setAxisPointsAction) {
-				int count = m_image->childCount<DatapickerPoint>(AbstractAspect::ChildIndexFlag::IncludeHidden);
-				if (count) {
-					auto button = QMessageBox::question(this,
-														i18n("Remove existing reference points?"),
-														i18n("All available reference points will be removed. Do you want to continue?"));
-					if (button != QMessageBox::Yes) {
-						currentPlotPointsTypeAction->setChecked(true);
-						return;
+			switch (m_mouseMode) {
+				case DatapickerImageView::MouseMode::ReferencePointsEntry: {
+					int count = m_image->childCount<DatapickerPoint>(AbstractAspect::ChildIndexFlag::IncludeHidden);
+					if (count) {
+						auto button = QMessageBox::question(this,
+															i18n("Remove existing reference points?"),
+															i18n("All available reference points will be removed. Do you want to continue?"));
+						if (button != QMessageBox::Yes) {
+							// Reset back to the old one
+							currentPlotPointsTypeAction->setChecked(true);
+							return;
+						}
 					}
+
+					m_image->setPlotPointsType(DatapickerImage::PointsType::AxisPoints);
+					break;
 				}
-
-				m_image->setPlotPointsType(DatapickerImage::PointsType::AxisPoints);
-			} else if (action == setCurvePointsAction)
-				m_image->setPlotPointsType(DatapickerImage::PointsType::CurvePoints);
-			else if (action == selectSegmentAction)
-				m_image->setPlotPointsType(DatapickerImage::PointsType::SegmentPoints);
-
-			currentPlotPointsTypeAction = action;
+				case DatapickerImageView::MouseMode::CurvePointsEntry:
+					m_image->setPlotPointsType(DatapickerImage::PointsType::CurvePoints);
+					break;
+				case DatapickerImageView::MouseMode::CurveSegmentsEntry:
+					m_image->setPlotPointsType(DatapickerImage::PointsType::SegmentPoints);
+					break;
+			}
 		}
 	}
+	currentPlotPointsTypeAction = action;
+	m_mouseMode = mode;
 }
 
 void DatapickerImageView::changeZoom(QAction* action) {
