@@ -208,7 +208,7 @@ AxisDock::AxisDock(QWidget* parent)
 	// template handler
 	auto* frame = new QFrame(this);
 	auto* hlayout = new QHBoxLayout(frame);
-	hlayout->setContentsMargins(0, 11, 0, 11);
+	hlayout->setContentsMargins(0, 0, 0, 0);
 
 	auto* templateHandler = new TemplateHandler(this, QLatin1String("Axis"));
 	hlayout->addWidget(templateHandler);
@@ -523,7 +523,7 @@ void AxisDock::updatePlotRangeList() {
 	if (m_axis->coordinateSystemCount() == 0)
 		return;
 
-	Axis::Orientation orientation = m_axis->orientation();
+	auto orientation = m_axis->orientation();
 	Range<double> logicalRange;
 	if (orientation == Axis::Orientation::Horizontal)
 		logicalRange = m_axis->plot()->range(Dimension::Y, m_axis->plot()->coordinateSystem(m_axis->coordinateSystemIndex())->index(Dimension::Y));
@@ -2047,7 +2047,7 @@ void AxisDock::loadConfigFromTemplate(KConfig& config) {
 }
 
 void AxisDock::loadConfig(KConfig& config) {
-	KConfigGroup group = config.group(QStringLiteral("Axis"));
+	auto group = config.group(QStringLiteral("Axis"));
 
 	// General
 	ui.cbOrientation->setCurrentIndex(group.readEntry(QStringLiteral("Orientation"), (int)m_axis->orientation()));
@@ -2071,8 +2071,8 @@ void AxisDock::loadConfig(KConfig& config) {
 	ui.chkShowScaleOffset->setChecked(group.readEntry(QStringLiteral("ShowScaleOffset"), static_cast<int>(m_axis->showScaleOffset())));
 
 	// Title
-	KConfigGroup axisLabelGroup = config.group(QStringLiteral("AxisLabel"));
-	labelWidget->loadConfig(axisLabelGroup);
+	auto axisTitleGroup = config.group(QStringLiteral("AxisTitle"));
+	labelWidget->loadConfig(axisTitleGroup);
 
 	// Line
 	lineWidget->loadConfig(group);
@@ -2153,10 +2153,11 @@ void AxisDock::loadConfig(KConfig& config) {
 }
 
 void AxisDock::saveConfigAsTemplate(KConfig& config) {
-	KConfigGroup group = config.group(QStringLiteral("Axis"));
+	auto group = config.group(QStringLiteral("Axis"));
 
 	// General
-	group.writeEntry(QStringLiteral("Orientation"), ui.cbOrientation->currentIndex());
+	auto orientation = (WorksheetElement::Orientation)ui.cbOrientation->currentIndex();
+	group.writeEntry(QStringLiteral("Orientation"), (int)orientation);
 
 	if (ui.cbPosition->currentIndex() == 2) {
 		group.writeEntry(QStringLiteral("Position"), static_cast<int>(Axis::Position::Centered));
@@ -2179,9 +2180,18 @@ void AxisDock::saveConfigAsTemplate(KConfig& config) {
 	group.writeEntry(QStringLiteral("ScalingFactor"), ui.sbScalingFactor->value());
 	group.writeEntry(QStringLiteral("ShowScaleOffset"), ui.chkShowScaleOffset->isChecked());
 
-	// Title
-	KConfigGroup axisLabelGroup = config.group(QStringLiteral("AxisLabel"));
-	labelWidget->saveConfig(axisLabelGroup);
+	// BOOKMARK(axis title): Title
+	auto axisTitleGroup = config.group(QStringLiteral("AxisTitle"));
+	labelWidget->saveConfig(axisTitleGroup);
+	// addtionally save rotation for x and y seperately to allow independent values
+	if (orientation == Axis::Orientation::Horizontal)
+		axisTitleGroup.writeEntry(QStringLiteral("RotationX"), labelWidget->ui.sbRotation->value());
+	else {
+		axisTitleGroup.writeEntry(QStringLiteral("RotationY"), labelWidget->ui.sbRotation->value());
+	}
+	// reset rotation used by the other axis (only used when other axis not saved)
+	// see Axis.cpp:BOOKMARK(axis title)
+	axisTitleGroup.writeEntry(QStringLiteral("Rotation"), 0);
 
 	// Line
 	lineWidget->saveConfig(group);
@@ -2190,7 +2200,7 @@ void AxisDock::saveConfigAsTemplate(KConfig& config) {
 	group.writeEntry(QStringLiteral("MajorTicksDirection"), ui.cbMajorTicksDirection->currentIndex());
 	group.writeEntry(QStringLiteral("MajorTicksType"), ui.cbMajorTicksType->itemData(ui.cbMajorTicksType->currentIndex()));
 	group.writeEntry(QStringLiteral("MajorTicksNumber"), ui.sbMajorTicksNumber->value());
-	bool numeric = m_axis->isNumeric();
+	const bool numeric = m_axis->isNumeric();
 	if (numeric)
 		group.writeEntry(QStringLiteral("MajorTicksIncrement"), QString::number(ui.sbMajorTicksSpacingNumeric->value()));
 	else
