@@ -18,11 +18,9 @@
 #endif
 
 void CommonTest::initTestCase() {
-	KLocalizedString::setApplicationDomain("labplot2");
-
-	// TODO: fix linkage
-	//	qRegisterMetaType<const AbstractAspect*>("const AbstractAspect*");
-	//	qRegisterMetaType<const AbstractColumn*>("const AbstractColumn*");
+	// always enable debugging
+	enableDebugTrace(true);
+	KLocalizedString::setApplicationDomain("labplot");
 
 #ifdef _WIN32
 //	if (AttachConsole(ATTACH_PARENT_PROCESS)) {
@@ -43,3 +41,11 @@ void CommonTest::listStack(QUndoStack* stack) {
 	qDebug() << "End list Undostack History";
 	qDebug() << "--------------------------";
 }
+
+void CommonTest::wait(int milliseconds) {
+	QTimer timer(this);
+	QEventLoop loop;
+	QTimer::connect(&timer, &QTimer::timeout, &loop, &QEventLoop::quit);
+	timer.start(milliseconds);
+	loop.exec();
+}
