@@ -4,7 +4,7 @@
 	Description          : Tests for data fitting
 	--------------------------------------------------------------------
 	SPDX-FileCopyrightText: 2017 Alexander Semke <alexander.semke@web.de>
-	SPDX-FileCopyrightText: 2018-2021 Stefan Gerlach <stefan.gerlach@uni.kn>
+	SPDX-FileCopyrightText: 2018-2025 Stefan Gerlach <stefan.gerlach@uni.kn>
 
 	SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -16,7 +16,12 @@
 class FitTest : public AnalysisTest {
 	Q_OBJECT
 
+private:
+	void printAndCheck(double value, double exact, double tol);
+
 private Q_SLOTS:
+	void addCurve();
+
 	// linear regression (see NIST/linear data)
 	void testLinearNorris();
 	void testLinearPontius();
@@ -27,36 +32,48 @@ private Q_SLOTS:
 	void testLinearFilip();
 
 	void testLinearWampler1();
+	void testLinearWampler1_custom(); // using custom model
 	void testLinearWampler2();
+	void testLinearWampler2_custom(); // using custom model
 	void testLinearWampler3();
+	void testLinearWampler3_custom(); // using custom model
 	void testLinearWampler4();
+	void testLinearWampler4_custom(); // using custom model
 	void testLinearWampler5();
+	void testLinearWampler5_custom(); // using custom model
 
 	void testLinearWP_OLS();
 	void testLinearR_lm2();
 
 	// non-linear regression
-	void testNonLinearMisra1a();
+	void testNonLinearMisra1a(); // first set of start values
 	void testNonLinearMisra1a_2(); // second set of start values
 	void testNonLinearMisra1a_3(); // third set of start values
-	void testNonLinearMisra1b();
+	void testNonLinearMisra1b(); // first set of start values
 	void testNonLinearMisra1b_2(); // second set of start values
 	void testNonLinearMisra1b_3(); // third set of start values
-	void testNonLinearMisra1c();
+	void testNonLinearMisra1c(); // first set of start values
 	void testNonLinearMisra1c_2(); // second set of start values
 	void testNonLinearMisra1c_3(); // third set of start values
-	void testNonLinearMisra1d();
+	void testNonLinearMisra1d(); // first set of start values
 	void testNonLinearMisra1d_2(); // second set of start values
 	void testNonLinearMisra1d_3(); // third set of start values
-	void testNonLinearMGH09();
+	void testNonLinearMGH09(); // first set of start values
 	void testNonLinearMGH09_2(); // second set of start values
-	void testNonLinearMGH09_3(); // third set of start values
-	void testNonLinearMGH10();
+	void testNonLinearMGH09_3(); // exact start values
+	void testNonLinearMGH10(); // first set of start values
 	void testNonLinearMGH10_2(); // second set of start values
 	void testNonLinearMGH10_3(); // third set of start values
-	void testNonLinearRat43();
+	void testNonLinearRat43(); // first set of start values
 	void testNonLinearRat43_2(); // second set of start values
 	void testNonLinearRat43_3(); // third set of start values
+	// more non-linear fits
+	void testNonLinearHahn1(); // first set of start values
+	void testNonLinearHahn1_2(); // second set of start values
+	void testNonLinearHahn1_3(); // exact start values
+	void testNonLinearBennett5(); // first set of start values
+	void testNonLinearBennett5_2(); // second set of start values
+	void testNonLinearBennett5_3(); // exact start values
 
 	void testNonLinearMichaelis_Menten();
 
