@@ -4,6 +4,7 @@
 	Description          : Tests for Axis methods
 	--------------------------------------------------------------------
 	SPDX-FileCopyrightText: 2022 Martin Marmsoler <martin.marmsoler@gmail.com>
+	SPDX-FileCopyrightText: 2022-2025 Alexander Semke <alexander.semke@web.de>
 
 	SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -36,11 +37,7 @@ private Q_SLOTS:
 
 	void automaticTicNumberUpdateDockMajorTicks();
 	void automaticTicNumberUpdateDockMinorTicks();
-
-	void columnLabelValues();
-	void columnLabelValuesMaxValues();
-
-	void customTextLabels();
+	void tickSpacingUpdateDockMajorTicks();
 };
 
 #endif // AXISTEST_H
