@@ -3,7 +3,7 @@
 	Project              : LabPlot
 	Description          : More tests for Axis methods
 	--------------------------------------------------------------------
-	SPDX-FileCopyrightText: 2022 Martin Marmsoler <martin.marmsoler@gmail.com>
+	SPDX-FileCopyrightText: 2022-2025 Martin Marmsoler <martin.marmsoler@gmail.com>
 
 	SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -34,8 +34,9 @@ private Q_SLOTS:
 	void customColumnNonMonotonicColumnValues();
 	void customColumnDateTime();
 
-	void autoScale();
-	void autoScale2();
+	void autoScaleLog10();
+	void autoScaleLog102();
+	void autoScaleLog102Vertical();
 };
 
 #endif // AXISTEST3_H
