@@ -3,7 +3,7 @@
 	Project              : LabPlot
 	Description          : Tests for BarPlot
 	--------------------------------------------------------------------
-	SPDX-FileCopyrightText: 2022 Alexander Semke <alexander.semke@web.de>
+	SPDX-FileCopyrightText: 2022-2023 Alexander Semke <alexander.semke@web.de>
 
 	SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -17,11 +17,16 @@ class BarPlotTest : public CommonTest {
 	Q_OBJECT
 
 private Q_SLOTS:
+	// bar plot
 	void testRange01();
 	void testRange02();
 	void testRange03();
 	void testRange04();
 	void testRange05();
+
+	// lollipop plot
+	void testRangeLollipopPlot01();
+	void testRangeLollipopPlot02();
 };
 
 #endif
