@@ -13,9 +13,9 @@
 #ifndef COLUMNTEST_H
 #define COLUMNTEST_H
 
-#include "../../CommonTest.h"
+#include "../../CommonMetaTest.h"
 
-class ColumnTest : public CommonTest {
+class ColumnTest : public CommonMetaTest {
 	Q_OBJECT
 
 private Q_SLOTS:
@@ -62,20 +62,31 @@ private Q_SLOTS:
 	void loadDateTimeFromProject();
 	void saveLoadDateTime();
 
-	void testIndexForValue();
+	void testIndexForValueStrictlyMonotonouslyRising();
+	void testIndexForValueMonotonouslyRising();
+	void indexForValueDatetimeStrictlyMonotonouslyRising();
+	void indexForValueDatetimeMonotonouslyRising();
+	void testIndexForValuePoints();
+	void testIndexForValueLines();
 	void testIndexForValueDoubleVector();
 
 	void testInsertRow();
 	void testRemoveRow();
 
 	void testFormula();
+	void testFormula2();
 	void testFormulaCell();
+	void testFormulaCellDefault();
 	void testFormulaCellInvalid();
 	void testFormulaCellConstExpression();
 	void testFormulaCellMulti();
+	void testFormulaCurrentColumnCell();
+	void testFormulaCurrentColumnCellDefaultValue();
 	void testFormulasmmin();
 	void testFormulasmmax();
 	void testFormulasma();
+	void testFormulapsample();
+	void testFormularsample();
 
 	void testFormulasMinColumnInvalid();
 
