@@ -23,10 +23,11 @@
 #include "backend/worksheet/plots/cartesian/XYCurve.h"
 #include "backend/worksheet/plots/cartesian/XYCurvePrivate.h"
 #include "backend/worksheet/plots/cartesian/XYEquationCurve.h"
-#include "commonfrontend/worksheet/WorksheetView.h"
-#include "kdefrontend/dockwidgets/AxisDock.h"
-#include "kdefrontend/dockwidgets/CartesianPlotDock.h"
-#include "kdefrontend/dockwidgets/XYCurveDock.h"
+#include "backend/worksheet/plots/cartesian/XYFunctionCurve.h"
+#include "frontend/dockwidgets/AxisDock.h"
+#include "frontend/dockwidgets/CartesianPlotDock.h"
+#include "frontend/dockwidgets/XYCurveDock.h"
+#include "frontend/worksheet/WorksheetView.h"
 
 #include <QAction>
 
@@ -686,8 +687,9 @@ void RetransformTest::TestAddCurve() {
 	data.type = XYEquationCurve::EquationType::Cartesian;
 	equationCurve->setEquationData(data);
 
-	auto list =
-		QStringList({QStringLiteral("Project/Worksheet/plot/x"), QStringLiteral("Project/Worksheet/plot/y"), QStringLiteral("Project/Worksheet/plot/f(x)")});
+	auto list = QStringList({i18n("Project") + QStringLiteral("/Worksheet/plot/x"),
+							 i18n("Project") + QStringLiteral("/Worksheet/plot/y"),
+							 i18n("Project") + QStringLiteral("/Worksheet/plot/f(x)")});
 	QCOMPARE(c.elementLogCount(false), list.count());
 	QCOMPARE(c.callCount(list.at(0)), 1);
 	QCOMPARE(c.callCount(list.at(1)), 1);
@@ -885,7 +887,10 @@ void RetransformTest::TestImportCSV() {
 	file.close();
 
 	AsciiFilter filter;
-	filter.setHeaderLine(1);
+	auto properties = filter.properties();
+	properties.headerEnabled = true;
+	properties.headerLine = 1;
+	filter.setProperties(properties);
 	filter.readDataFromFile(file.fileName(), spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	QCOMPARE(spreadsheet->rowCount(), 3);
@@ -917,8 +922,9 @@ void RetransformTest::TestImportCSV() {
 	QCOMPARE(c.logsYScaleRetransformed.at(0).plot, p);
 	QCOMPARE(c.logsYScaleRetransformed.at(0).index, 0);
 
-	auto list = QStringList(
-		{QStringLiteral("Project/Worksheet/plot/x"), QStringLiteral("Project/Worksheet/plot/y"), QStringLiteral("Project/Worksheet/plot/xy-curve")});
+	auto list = QStringList({i18n("Project") + QStringLiteral("/Worksheet/plot/x"),
+							 i18n("Project") + QStringLiteral("/Worksheet/plot/y"),
+							 i18n("Project") + QStringLiteral("/Worksheet/plot/xy-curve")});
 	QCOMPARE(c.elementLogCount(false), list.count());
 	for (auto& s : list) {
 		qDebug() << s;
@@ -995,10 +1001,6 @@ void RetransformTest::TestImportCSVInvalidateCurve() {
 	QString savePath;
 	SAVE_FILE("testfile", fileContent);
 
-	filter.setCommentCharacter(QString());
-	filter.setSeparatingCharacter(QStringLiteral(";"));
-	filter.setHeaderEnabled(true);
-	filter.setHeaderLine(1);
 	filter.readDataFromFile(savePath, spreadsheet, AbstractFileFilter::ImportMode::Replace);
 
 	// the assignment to the data columns got lost since the columns were renamed
@@ -1011,7 +1013,7 @@ void RetransformTest::TestImportCSVInvalidateCurve() {
 
 	// the curve that lost the column assignemnt should be retransformed
 	QCOMPARE(c.elementLogCount(false), 1);
-	QCOMPARE(c.callCount(QStringLiteral("Project/plot/curve")), 1);
+	QCOMPARE(c.callCount(i18n("Project") + QStringLiteral("/plot/curve")), 1);
 }
 
 void RetransformTest::TestSetScale() {
@@ -1074,11 +1076,11 @@ void RetransformTest::TestSetScale() {
 
 	auto list = QStringList({// data rect of the plot does not change, so retransforming the
 							 // plot is not needed
-							 QStringLiteral("Project/Worksheet/Plot/x"),
-							 QStringLiteral("Project/Worksheet/Plot/x2"),
-							 QStringLiteral("Project/Worksheet/Plot/y"),
-							 QStringLiteral("Project/Worksheet/Plot/y2"),
-							 QStringLiteral("Project/Worksheet/Plot/curve")});
+							 i18n("Project") + QStringLiteral("/Worksheet/Plot/x"),
+							 i18n("Project") + QStringLiteral("/Worksheet/Plot/x2"),
+							 i18n("Project") + QStringLiteral("/Worksheet/Plot/y"),
+							 i18n("Project") + QStringLiteral("/Worksheet/Plot/y2"),
+							 i18n("Project") + QStringLiteral("/Worksheet/Plot/curve")});
 
 	plot->setRangeScale(Dimension::X, 0, RangeT::Scale::Log10);
 
@@ -1959,6 +1961,97 @@ void RetransformTest::testPlotRecalcRetransform() {
 	}
 }
 
+void RetransformTest::xyFunctionCurve() {
+	Project project;
+	auto* ws = new Worksheet(QStringLiteral("Worksheet"));
+	QVERIFY(ws != nullptr);
+	project.addChild(ws);
+
+	RetransformCallCounter c;
+
+	auto* p = new CartesianPlot(QStringLiteral("plot"));
+	p->setType(CartesianPlot::Type::TwoAxes); // Otherwise no axis are created
+	QVERIFY(p != nullptr);
+	ws->addChild(p);
+	c.aspectAdded(p);
+	const auto& axes = p->children<Axis>();
+	QCOMPARE(axes.count(), 2);
+	c.aspectAdded(axes.at(0));
+	c.aspectAdded(axes.at(1));
+
+	p->addChild(new XYEquationCurve(QLatin1String("eq")));
+
+	auto equationCurves = p->children(AspectType::XYEquationCurve);
+	QCOMPARE(equationCurves.count(), 1);
+	auto* equationCurve = static_cast<XYEquationCurve*>(equationCurves.at(0));
+	XYEquationCurve::EquationData data;
+	data.count = 100;
+	data.expression1 = QStringLiteral("x");
+	data.expression2 = QString();
+	data.min = QStringLiteral("1");
+	data.max = QStringLiteral("100");
+	data.type = XYEquationCurve::EquationType::Cartesian;
+	equationCurve->setEquationData(data);
+
+	c.aspectAdded(equationCurve);
+
+	QCOMPARE(equationCurve->xColumn()->rowCount(), data.count);
+
+	p->addChild(new XYFunctionCurve(QLatin1String("eq2")));
+	auto functionCurves = p->children(AspectType::XYFunctionCurve);
+	QCOMPARE(functionCurves.count(), 1);
+	auto* functionCurve = static_cast<XYFunctionCurve*>(functionCurves.at(0));
+
+	c.aspectAdded(functionCurve);
+
+	c.resetRetransformCount();
+
+	functionCurve->setFunction(QStringLiteral("2*x"), {QStringLiteral("x")}, {equationCurve});
+
+	{
+		const auto stat = c.statistic(false);
+		QCOMPARE(stat.count(), 4); // equationCurve, functionCurve, xAxis and yAxis are inside
+		QCOMPARE(stat.contains(equationCurve->path()), true);
+		QCOMPARE(stat.contains(functionCurve->path()), true);
+		QCOMPARE(stat.contains(axes.at(0)->path()), true);
+		QCOMPARE(stat.contains(axes.at(1)->path()), true);
+		QVERIFY(c.calledExact(1, false));
+		QCOMPARE(c.logsXScaleRetransformed.count(), 0); // only the y range changed
+		QCOMPARE(c.logsYScaleRetransformed.count(), 1);
+	}
+
+	{
+		const auto* xColumn = functionCurve->xColumn();
+		const auto* yColumn = functionCurve->yColumn();
+		QCOMPARE(xColumn->rowCount(), data.count);
+		QCOMPARE(yColumn->rowCount(), data.count);
+		for (int i = 0; i < xColumn->rowCount(); i++) {
+			VALUES_EQUAL(xColumn->valueAt(i), i + 1.);
+			VALUES_EQUAL(yColumn->valueAt(i), (i + 1.) * 2.0);
+		}
+	}
+
+	c.resetRetransformCount();
+
+	data.expression1 = QStringLiteral("2*x");
+	data.min = QStringLiteral("10");
+	data.max = QStringLiteral("1000");
+	equationCurve->setEquationData(data);
+
+	{
+		const auto stat = c.statistic(false);
+		QCOMPARE(stat.count(), 4); // equationCurve, functionCurve, xAxis and yAxis are inside
+		QCOMPARE(stat.contains(equationCurve->path()), true);
+		QCOMPARE(stat.contains(functionCurve->path()), true);
+		QCOMPARE(stat.contains(axes.at(0)->path()), true);
+		QCOMPARE(stat.contains(axes.at(1)->path()), true);
+		// QVERIFY(c.calledExact(1, false)); // TODO: how to verify that retransform gets called only once?
+		QCOMPARE(c.logsXScaleRetransformed.count(), 1);
+		QVERIFY(c.logsYScaleRetransformed.count() >= 1);
+		// QCOMPARE(c.logsYScaleRetransformed.count(), 1);
+	}
+}
+
 // ############################################################################################
 // ############################################################################################
 // ############################################################################################
