@@ -4,6 +4,7 @@
 	Description          : Tests for AbstractAspect
 	--------------------------------------------------------------------
 	SPDX-FileCopyrightText: 2023 Martin Marmsoler <martin.marmsoler@gmail.com>
+	SPDX-FileCopyrightText: 2023-2025 Alexander Semke <alexander.semke@web.de>
 
 	SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -18,9 +19,17 @@ class AbstractAspectTest : public CommonTest {
 
 private Q_SLOTS:
 	void name();
+
+	void testAddChildUndoRedo();
+	void testDuplicateChildUndoRedo();
+
 	void copyPaste();
 	void saveLoad();
 
+	void pasteFitCurveSourceSpreadsheet();
+	void pasteFitCurveSourceCurve();
+	void pasteFitCurveSourceHistogram();
+
 	void moveUp();
 	void moveDown();
 	void moveUpDown();
