@@ -553,6 +553,46 @@ void StatisticalPlotsTest::testPBChartDuplicate() {
 	QCOMPARE(children.size(), 2);
 }
 
+/*!
+ * perform modification on the PBC leading to the resize and modifications of the internal
+ * columns and curves and check the entries on the undo stack - the internal changes should
+ * not be visible on the undo stack, only the operation that was triggered by the user.
+ */
+void StatisticalPlotsTest::testPBChartUndoRedo() {
+	Project project;
+
+	// prepare the data, same as in testPBChartXmRAverage()
+	auto* column = new Column(QLatin1String("data"), AbstractColumn::ColumnMode::Integer);
+	column->setIntegers({11, 4, 6, 4, 5, 7, 5, 4, 7, 12, 4, 2, 4, 5, 6, 4, 2, 2, 5, 9, 5, 6, 5, 9});
+
+	// prepare the worksheet + plot
+	auto* ws = new Worksheet(QStringLiteral("worksheet"));
+	project.addChild(ws);
+
+	auto* p = new CartesianPlot(QStringLiteral("plot"));
+	ws->addChild(p);
+
+	auto* pbc = new ProcessBehaviorChart(QStringLiteral("pbc"));
+	pbc->setType(ProcessBehaviorChart::Type::XmR);
+	p->addChild(pbc);
+
+	// check the initial number of entries on the undo stack
+	auto* stack = project.undoStack();
+	QCOMPARE(stack->count(), 3);
+
+	// change the sub-type which changes the number of points/samples on X
+	pbc->setType(ProcessBehaviorChart::Type::S);
+	QCOMPARE(stack->count(), 4);
+	stack->undo();
+	QCOMPARE(stack->count(), 4);
+
+	// use an empty column as the data source which will empty all internal columns in pbc
+	pbc->setDataColumn(new Column(QLatin1String("temp")));
+	QCOMPARE(stack->count(), 4);
+	stack->undo();
+	QCOMPARE(stack->count(), 4);
+}
+
 /*!
  * test the X (XmR) chart using Average for the limits, the example is taken from Wheeler "Making Sense of Data", chapter seven.
  */
