@@ -13,8 +13,8 @@
 #include "backend/worksheet/Worksheet.h"
 #include "backend/worksheet/plots/cartesian/CartesianPlot.h"
 #include "backend/worksheet/plots/cartesian/XYEquationCurve.h"
-#include "commonfrontend/widgets/NumberSpinBox.h"
-#include "src/kdefrontend/dockwidgets/CartesianPlotDock.h"
+#include "frontend/dockwidgets/CartesianPlotDock.h"
+#include "frontend/widgets/NumberSpinBox.h"
 
 #include <QLineEdit>
 #include <QLocale>
@@ -939,7 +939,7 @@ void SpinBoxTest::numberSpinBoxFeedback() {
 	sb.keyPressEvent(&event);
 	QCOMPARE(valueChangedCounter, 2);
 	QCOMPARE(lastValue, 7);
-	QCOMPARE(sb.toolTip(), QStringLiteral("Invalid value entered. Valid value: %1").arg(0));
+	QCOMPARE(sb.toolTip(), i18n("Invalid value entered. Valid value: %1", QString::number(0)));
 	QCOMPARE(sb.m_waitFeedback, false);
 
 	sb.keyPressEvent(&event);
@@ -1247,7 +1247,7 @@ void SpinBoxTest::thousandSeparatorScrolling2() {
 }
 
 void SpinBoxTest::thousandSeparatorScrollingSeparatorPosition() {
-	QSKIP("Undecided what to do");
+	QSKIP("Undecided what to do", QTest::SkipSingle);
 	NumberSpinBox sb;
 	sb.setLocale(QLocale(QLocale::German));
 	QCOMPARE(sb.locale().decimalPoint(), QLatin1Char(','));
