@@ -13,4 +13,4 @@ print(s)
 while True:
   cpu_percent = str(psutil.cpu_percent(interval=2.))
   s.write(cpu_percent)
-  print 'written ' + cpu_percent
+  print('written ' + cpu_percent)
