@@ -10,9 +10,9 @@
 #ifndef BINARYFILTERTEST_H
 #define BINARYFILTERTEST_H
 
-#include "../../CommonTest.h"
+#include "../../CommonMetaTest.h"
 
-class BinaryFilterTest : public CommonTest {
+class BinaryFilterTest : public CommonMetaTest {
 	Q_OBJECT
 
 private Q_SLOTS:
