@@ -4,6 +4,7 @@
 	Description          : Tests for the JSON I/O-filter.
 	--------------------------------------------------------------------
 	SPDX-FileCopyrightText: 2018 Andrey Cygankov <craftplace.ms@gmail.com>
+	SPDX-FileCopyrightText: 2024 Stefan Gerlach <stefan.gerlach@uni.kn>
 	SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -13,13 +14,6 @@
 
 #include <KLocalizedString>
 
-void JSONFilterTest::initTestCase() {
-	// needed in order to have the signals triggered by SignallingUndoCommand, see LabPlot.cpp
-	// TODO: redesign/remove this
-	qRegisterMetaType<const AbstractAspect*>("const AbstractAspect*");
-	qRegisterMetaType<const AbstractColumn*>("const AbstractColumn*");
-}
-
 void JSONFilterTest::testArrayImport() {
 	Spreadsheet spreadsheet(QStringLiteral("test"), false);
 	JsonFilter filter;
@@ -42,8 +36,8 @@ void JSONFilterTest::testArrayImport() {
 	QCOMPARE(spreadsheet.column(2)->plotDesignation(), AbstractColumn::PlotDesignation::Y);
 
 	QCOMPARE(spreadsheet.column(0)->name(), i18n("index"));
-	QCOMPARE(spreadsheet.column(1)->name(), QLatin1String("Column 1")); // TODO is translatable in JsonFilter
-	QCOMPARE(spreadsheet.column(2)->name(), QLatin1String("Column 2"));
+	QCOMPARE(spreadsheet.column(1)->name(), i18n("Column") + QStringLiteral(" 1"));
+	QCOMPARE(spreadsheet.column(2)->name(), i18n("Column") + QStringLiteral(" 2"));
 
 	QCOMPARE(spreadsheet.column(0)->integerAt(0), 1);
 	QCOMPARE(spreadsheet.column(0)->integerAt(1), 2);
