@@ -374,7 +374,7 @@ void MatioFilterTest::testImportStructPortion() {
 }
 
 void MatioFilterTest::testImportCell() {
-	QSKIP("Failing because of AddressSanitizer: heap-buffer-overflow");
+	QSKIP("Failing because of AddressSanitizer: heap-buffer-overflow", QTest::SkipSingle);
 	Spreadsheet spreadsheet(QStringLiteral("test"), false);
 	MatioFilter filter;
 
