@@ -10,9 +10,9 @@
 #ifndef NETCDFFILTERTEST_H
 #define NETCDFFILTERTEST_H
 
-#include "../../CommonTest.h"
+#include "../../CommonMetaTest.h"
 
-class NetCDFFilterTest : public CommonTest {
+class NetCDFFilterTest : public CommonMetaTest {
 	Q_OBJECT
 
 private Q_SLOTS:
