@@ -10,9 +10,9 @@
 #ifndef ODSFILTERTEST_H
 #define ODSFILTERTEST_H
 
-#include "../../CommonTest.h"
+#include "../../CommonMetaTest.h"
 
-class OdsFilterTest : public CommonTest {
+class OdsFilterTest : public CommonMetaTest {
 	Q_OBJECT
 
 private Q_SLOTS:
