@@ -434,7 +434,7 @@ void ProjectImportTest::testOrigin_2folder_with_graphs() {
 	auto* plot = dynamic_cast<CartesianPlot*>(w1->child<CartesianPlot>(0));
 	QVERIFY(plot != nullptr);
 
-	QCOMPARE(plot->name(), QLatin1String("Plot1"));
+	QCOMPARE(plot->name(), i18n("Plot%1", QString::number(1)));
 
 	auto* xAxis = dynamic_cast<Axis*>(plot->child<Axis>(0));
 	QVERIFY(xAxis != nullptr);
@@ -445,7 +445,7 @@ void ProjectImportTest::testOrigin_2folder_with_graphs() {
 
 	auto* legend = dynamic_cast<CartesianPlotLegend*>(plot->child<CartesianPlotLegend>(0));
 	QVERIFY(legend != nullptr);
-	QCOMPARE(legend->name(), QStringLiteral("legend"));
+	QCOMPARE(legend->name(), i18n("legend"));
 
 	auto* curve = dynamic_cast<XYCurve*>(plot->child<XYCurve>(0));
 	QVERIFY(curve != nullptr);
@@ -468,7 +468,11 @@ void ProjectImportTest::testOrigin_2folder_with_graphs() {
 	auto* symbol = curve->symbol();
 	QVERIFY(symbol != nullptr);
 	QCOMPARE(symbol->style(), Symbol::Style::SquareHalf);
+#if defined(HAVE_WINDOWS)
+	QCOMPARE(symbol->size(), 44.94210847045);
+#else
 	QCOMPARE(symbol->size(), 89.8842169409);
+#endif
 	// TODO: more symbol props
 
 	// Folder 2
@@ -490,7 +494,7 @@ void ProjectImportTest::testOrigin_2folder_with_graphs() {
 	plot = dynamic_cast<CartesianPlot*>(w2->child<CartesianPlot>(0));
 	QVERIFY(plot != nullptr);
 
-	QCOMPARE(plot->name(), QLatin1String("Plot1"));
+	QCOMPARE(plot->name(), i18n("Plot%1", QString::number(1)));
 
 	xAxis = dynamic_cast<Axis*>(plot->child<Axis>(0));
 	QVERIFY(xAxis != nullptr);
@@ -501,7 +505,7 @@ void ProjectImportTest::testOrigin_2folder_with_graphs() {
 
 	legend = dynamic_cast<CartesianPlotLegend*>(plot->child<CartesianPlotLegend>(0));
 	QVERIFY(legend != nullptr);
-	QCOMPARE(legend->name(), QStringLiteral("legend"));
+	QCOMPARE(legend->name(), i18n("legend"));
 
 	curve = dynamic_cast<XYCurve*>(plot->child<XYCurve>(0));
 	QVERIFY(curve != nullptr);
@@ -524,7 +528,11 @@ void ProjectImportTest::testOrigin_2folder_with_graphs() {
 	symbol = curve->symbol();
 	QVERIFY(symbol != nullptr);
 	QCOMPARE(symbol->style(), Symbol::Style::Hexagon);
+#if defined(HAVE_WINDOWS)
+	QCOMPARE(symbol->size(), 44.94210847045);
+#else
 	QCOMPARE(symbol->size(), 89.8842169409);
+#endif
 	// TODO: more symbol props
 }
 
@@ -558,7 +566,7 @@ void ProjectImportTest::testOrigin_2graphs() {
 	auto* plot = dynamic_cast<CartesianPlot*>(w2->child<CartesianPlot>(0));
 	QVERIFY(plot != nullptr);
 
-	QCOMPARE(plot->name(), QLatin1String("Plot1"));
+	QCOMPARE(plot->name(), i18n("Plot%1", QString::number(1)));
 
 	auto* xAxis = dynamic_cast<Axis*>(plot->child<Axis>(0));
 	QVERIFY(xAxis != nullptr);
@@ -569,7 +577,7 @@ void ProjectImportTest::testOrigin_2graphs() {
 
 	auto* legend = dynamic_cast<CartesianPlotLegend*>(plot->child<CartesianPlotLegend>(0));
 	QVERIFY(legend != nullptr);
-	QCOMPARE(legend->name(), QStringLiteral("legend"));
+	QCOMPARE(legend->name(), i18n("legend"));
 
 	auto* curve = dynamic_cast<XYCurve*>(plot->child<XYCurve>(0));
 	QVERIFY(curve != nullptr);
@@ -593,7 +601,12 @@ void ProjectImportTest::testOrigin_2graphs() {
 	auto* symbol = curve->symbol();
 	QVERIFY(symbol != nullptr);
 	QCOMPARE(symbol->style(), Symbol::Style::Hexagon);
+#if defined(HAVE_WINDOWS)
+	WARN(std::setprecision(15) << symbol->size())
+	QCOMPARE(symbol->size(), 44.94210847045);
+#else
 	QCOMPARE(symbol->size(), 89.8842169409);
+#endif
 	// TODO: more symbol props
 
 	// Graph 1
@@ -604,7 +617,7 @@ void ProjectImportTest::testOrigin_2graphs() {
 	plot = dynamic_cast<CartesianPlot*>(w1->child<CartesianPlot>(0));
 	QVERIFY(plot != nullptr);
 
-	QCOMPARE(plot->name(), QLatin1String("Plot1"));
+	QCOMPARE(plot->name(), i18n("Plot%1", QString::number(1)));
 
 	xAxis = dynamic_cast<Axis*>(plot->child<Axis>(0));
 	QVERIFY(xAxis != nullptr);
@@ -615,7 +628,7 @@ void ProjectImportTest::testOrigin_2graphs() {
 
 	legend = dynamic_cast<CartesianPlotLegend*>(plot->child<CartesianPlotLegend>(0));
 	QVERIFY(legend != nullptr);
-	QCOMPARE(legend->name(), QStringLiteral("legend"));
+	QCOMPARE(legend->name(), i18n("legend"));
 
 	curve = dynamic_cast<XYCurve*>(plot->child<XYCurve>(0));
 	QVERIFY(curve != nullptr);
@@ -638,7 +651,11 @@ void ProjectImportTest::testOrigin_2graphs() {
 	symbol = curve->symbol();
 	QVERIFY(symbol != nullptr);
 	QCOMPARE(symbol->style(), Symbol::Style::SquareHalf);
+#if defined(HAVE_WINDOWS)
+	QCOMPARE(symbol->size(), 44.94210847045);
+#else
 	QCOMPARE(symbol->size(), 89.8842169409);
+#endif
 	// TODO: more symbol props
 
 	// Book 1
@@ -690,7 +707,7 @@ void ProjectImportTest::testOriginHistogram() {
 
 	auto* plot = dynamic_cast<CartesianPlot*>(worksheet->child<CartesianPlot>(0));
 	QVERIFY(plot != nullptr);
-	QCOMPARE(plot->name(), QLatin1String("Plot1"));
+	QCOMPARE(plot->name(), i18n("Plot%1", QString::number(1)));
 
 	auto* histogram = dynamic_cast<Histogram*>(plot->child<Histogram>(0));
 	QVERIFY(histogram != nullptr);
@@ -706,7 +723,7 @@ void ProjectImportTest::testOriginHistogram() {
 
 	plot = dynamic_cast<CartesianPlot*>(worksheet->child<CartesianPlot>(0));
 	QVERIFY(plot != nullptr);
-	QCOMPARE(plot->name(), QLatin1String("Plot1"));
+	QCOMPARE(plot->name(), i18n("Plot%1", QString::number(1)));
 
 	histogram = dynamic_cast<Histogram*>(plot->child<Histogram>(0));
 	QVERIFY(histogram != nullptr);
@@ -749,7 +766,7 @@ void ProjectImportTest::testOriginBarPlot() {
 
 	auto* plot = dynamic_cast<CartesianPlot*>(worksheet->child<CartesianPlot>(0));
 	QVERIFY(plot != nullptr);
-	QCOMPARE(plot->name(), QLatin1String("Plot1"));
+	QCOMPARE(plot->name(), i18n("Plot%1", QString::number(1)));
 
 	auto* barPlot = dynamic_cast<BarPlot*>(plot->child<BarPlot>(0));
 	QVERIFY(barPlot != nullptr);
@@ -765,7 +782,7 @@ void ProjectImportTest::testOriginBarPlot() {
 
 	plot = dynamic_cast<CartesianPlot*>(worksheet->child<CartesianPlot>(0));
 	QVERIFY(plot != nullptr);
-	QCOMPARE(plot->name(), QLatin1String("Plot1"));
+	QCOMPARE(plot->name(), i18n("Plot%1", QString::number(1)));
 
 	barPlot = dynamic_cast<BarPlot*>(plot->child<BarPlot>(0));
 	QVERIFY(barPlot != nullptr);
