@@ -16,6 +16,11 @@
 #include <gsl/gsl_rng.h>
 
 void ROOTFilterTest::importFile1() {
+#ifdef _WIN32
+	// TODO: Crashes with "Caught unhandled exception"
+	QSKIP("To be fixed", QTest::SkipSingle);
+#endif
+
 	const QString& fileName = QFINDTESTDATA(QLatin1String("data/advanced_zlib.root"));
 
 	Spreadsheet spreadsheet(QStringLiteral("test"), false);
