@@ -10,9 +10,9 @@
 #ifndef ROOTFILTERTEST_H
 #define ROOTFILTERTEST_H
 
-#include "../../CommonTest.h"
+#include "../../CommonMetaTest.h"
 
-class ROOTFilterTest : public CommonTest {
+class ROOTFilterTest : public CommonMetaTest {
 	Q_OBJECT
 
 private Q_SLOTS:
