@@ -1,8 +1,8 @@
 namespace LowPassFilter_Transient {
 
-const QString filename = "transient/LowPassFilter.raw";
+const QString filename = QStringLiteral("transient/LowPassFilter.raw");
 
-QString refFileInfoString = R"(Title: * C:\users\martin\My Documents\Labplot\LowPassFilter.asc
+QString refFileInfoString = QLatin1String(R"(Title: * C:\users\martin\My Documents\Labplot\LowPassFilter.asc
 <br>Date: Fri Mar 11 16:13:24 2022
 <br>Plotname: Transient Analysis
 <br>Flags: real forward
@@ -17,15 +17,15 @@ QString refFileInfoString = R"(Title: * C:\users\martin\My Documents\Labplot\Low
 <br>	3	I(C1)	device_current
 <br>	4	I(R1)	device_current
 <br>	5	I(V1)	device_current
-)"; // last \n is important
+)"); // last \n is important
 
 const int refDataRowCount = 535;
 const int numberPreviewData = 103;
 
-QStringList columnNames = {	"time, time",
-							"V(n001), voltage",
-                            "V(n002), voltage",
-                            "I(C1), device_current",
-                            "I(R1), device_current",
-							"I(V1), device_current"};
+QStringList columnNames = {QStringLiteral("time, time"),
+						   QStringLiteral("V(n001), voltage"),
+						   QStringLiteral("V(n002), voltage"),
+						   QStringLiteral("I(C1), device_current"),
+						   QStringLiteral("I(R1), device_current"),
+						   QStringLiteral("I(V1), device_current")};
 }
